@@ -12,6 +12,9 @@ logging.error("Example log %s, %s", "foo", "bar", "baz", *args)
 # do not handle calls with **kwargs
 logging.error("Example log %s, %s", "foo", "bar", "baz", **kwargs)
 
+# do not handle keyword arguments
+logging.error("%(objects)d modifications: %(modifications)d errors: %(errors)d", {"objects": 1, "modifications": 1, "errors": 1})
+
 import warning
 
 warning.warning("Hello %s", "World!", "again")
