@@ -1,4 +1,5 @@
 bla = b"bla"
+d = {"a": b"bla", "b": b"bla", "c": b"bla"}
 
 
 def foo(one_arg):
@@ -7,6 +8,8 @@ def foo(one_arg):
 
 f"{str(bla)}, {repr(bla)}, {ascii(bla)}"  # RUF010
 
+f"{str(d['a'])}, {repr(d['b'])}, {ascii(d['c'])}"  # RUF010
+
 f"{foo(bla)}"  # OK
 
 f"{str(bla, 'ascii')}, {str(bla, encoding='cp1255')}"  # OK
