@@ -1,6 +1,6 @@
 use crate::message::{Emitter, EmitterContext, Message};
 use crate::registry::AsRule;
-use ruff_python_ast::source_code::{OneIndexed, SourceLocation};
+use ruff_python_ast::source_code::SourceLocation;
 use std::io::Write;
 
 /// Generate error logging commands for Azure Pipelines format.
@@ -19,10 +19,7 @@ impl Emitter for AzureEmitter {
             let location = if context.is_jupyter_notebook(message.filename()) {
                 // We can't give a reasonable location for the structured formats,
                 // so we show one that's clearly a fallback
-                SourceLocation {
-                    row: OneIndexed::from_zero_indexed(0),
-                    column: OneIndexed::from_zero_indexed(0),
-                }
+                SourceLocation::default()
             } else {
                 message.compute_start_location()
             };
