@@ -1,11 +1,11 @@
 use ruff_text_size::TextRange;
 
-use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Edit};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Edit, Fix};
 use ruff_macros::{derive_message_formats, violation};
 use ruff_python_ast::source_code::Locator;
 
 use crate::registry::Rule;
-use crate::settings::{flags, Settings};
+use crate::settings::Settings;
 
 use super::detection::comment_contains_code;
 
@@ -46,19 +46,22 @@ fn is_standalone_comment(line: &str) -> bool {
 }
 
 /// ERA001
-pub fn commented_out_code(
+pub(crate) fn commented_out_code(
     locator: &Locator,
     range: TextRange,
     settings: &Settings,
-    autofix: flags::Autofix,
 ) -> Option<Diagnostic> {
     let line = locator.full_lines(range);
 
     // Verify that the comment is on its own line, and that it contains code.
     if is_standalone_comment(line) && comment_contains_code(line, &settings.task_tags[..]) {
         let mut diagnostic = Diagnostic::new(CommentedOutCode, range);
-        if autofix.into() && settings.rules.should_fix(Rule::CommentedOutCode) {
-            diagnostic.set_fix(Edit::range_deletion(locator.full_lines_range(range)));
+
+        if settings.rules.should_fix(Rule::CommentedOutCode) {
+            #[allow(deprecated)]
+            diagnostic.set_fix(Fix::unspecified(Edit::range_deletion(
+                locator.full_lines_range(range),
+            )));
         }
         Some(diagnostic)
     } else {
