@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{Expr, ExprKind, Stmt};
+use rustpython_parser::ast::{Expr, Ranged, Stmt};
 
 use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -419,8 +419,8 @@ fn is_none_returning(body: &[Stmt]) -> bool {
     visitor.visit_body(body);
     for expr in visitor.returns.into_iter().flatten() {
         if !matches!(
-            expr.node,
-            ExprKind::Constant(ref constant) if constant.value.is_none()
+            expr,
+            Expr::Constant(ref constant) if constant.value.is_none()
         ) {
             return false;
         }
@@ -434,10 +434,11 @@ fn check_dynamically_typed<F>(
     annotation: &Expr,
     func: F,
     diagnostics: &mut Vec<Diagnostic>,
+    is_overridden: bool,
 ) where
     F: FnOnce() -> String,
 {
-    if checker.ctx.match_typing_expr(annotation, "Any") {
+    if !is_overridden && checker.ctx.match_typing_expr(annotation, "Any") {
         diagnostics.push(Diagnostic::new(
             AnyType { name: func() },
             annotation.range(),
@@ -468,7 +469,7 @@ pub(crate) fn definition(
         _ => return vec![],
     };
 
-    let (name, args, returns, body) = match_function_def(stmt);
+    let (name, args, returns, body, decorator_list) = match_function_def(stmt);
     // Keep track of whether we've seen any typed arguments or return values.
     let mut has_any_typed_arg = false; // Any argument has been typed?
     let mut has_typed_return = false; // Return value has been typed?
@@ -478,6 +479,8 @@ pub(crate) fn definition(
     // unless configured to suppress ANN* for declarations that are fully untyped.
     let mut diagnostics = Vec::new();
 
+    let is_overridden = visibility::is_override(&checker.ctx, decorator_list);
+
     // ANN001, ANN401
     for arg in args
         .posonlyargs
@@ -492,19 +495,20 @@ pub(crate) fn definition(
         )
     {
         // ANN401 for dynamically typed arguments
-        if let Some(annotation) = &arg.node.annotation {
+        if let Some(annotation) = &arg.annotation {
             has_any_typed_arg = true;
             if checker.settings.rules.enabled(Rule::AnyType) {
                 check_dynamically_typed(
                     checker,
                     annotation,
-                    || arg.node.arg.to_string(),
+                    || arg.arg.to_string(),
                     &mut diagnostics,
+                    is_overridden,
                 );
             }
         } else {
             if !(checker.settings.flake8_annotations.suppress_dummy_args
-                && checker.settings.dummy_variable_rgx.is_match(&arg.node.arg))
+                && checker.settings.dummy_variable_rgx.is_match(&arg.arg))
             {
                 if checker
                     .settings
@@ -513,7 +517,7 @@ pub(crate) fn definition(
                 {
                     diagnostics.push(Diagnostic::new(
                         MissingTypeFunctionArgument {
-                            name: arg.node.arg.to_string(),
+                            name: arg.arg.to_string(),
                         },
                         arg.range(),
                     ));
@@ -524,22 +528,28 @@ pub(crate) fn definition(
 
     // ANN002, ANN401
     if let Some(arg) = &args.vararg {
-        if let Some(expr) = &arg.node.annotation {
+        if let Some(expr) = &arg.annotation {
             has_any_typed_arg = true;
             if !checker.settings.flake8_annotations.allow_star_arg_any {
                 if checker.settings.rules.enabled(Rule::AnyType) {
-                    let name = &arg.node.arg;
-                    check_dynamically_typed(checker, expr, || format!("*{name}"), &mut diagnostics);
+                    let name = &arg.arg;
+                    check_dynamically_typed(
+                        checker,
+                        expr,
+                        || format!("*{name}"),
+                        &mut diagnostics,
+                        is_overridden,
+                    );
                 }
             }
         } else {
             if !(checker.settings.flake8_annotations.suppress_dummy_args
-                && checker.settings.dummy_variable_rgx.is_match(&arg.node.arg))
+                && checker.settings.dummy_variable_rgx.is_match(&arg.arg))
             {
                 if checker.settings.rules.enabled(Rule::MissingTypeArgs) {
                     diagnostics.push(Diagnostic::new(
                         MissingTypeArgs {
-                            name: arg.node.arg.to_string(),
+                            name: arg.arg.to_string(),
                         },
                         arg.range(),
                     ));
@@ -550,27 +560,28 @@ pub(crate) fn definition(
 
     // ANN003, ANN401
     if let Some(arg) = &args.kwarg {
-        if let Some(expr) = &arg.node.annotation {
+        if let Some(expr) = &arg.annotation {
             has_any_typed_arg = true;
             if !checker.settings.flake8_annotations.allow_star_arg_any {
                 if checker.settings.rules.enabled(Rule::AnyType) {
-                    let name = &arg.node.arg;
+                    let name = &arg.arg;
                     check_dynamically_typed(
                         checker,
                         expr,
                         || format!("**{name}"),
                         &mut diagnostics,
+                        is_overridden,
                     );
                 }
             }
         } else {
             if !(checker.settings.flake8_annotations.suppress_dummy_args
-                && checker.settings.dummy_variable_rgx.is_match(&arg.node.arg))
+                && checker.settings.dummy_variable_rgx.is_match(&arg.arg))
             {
                 if checker.settings.rules.enabled(Rule::MissingTypeKwargs) {
                     diagnostics.push(Diagnostic::new(
                         MissingTypeKwargs {
-                            name: arg.node.arg.to_string(),
+                            name: arg.arg.to_string(),
                         },
                         arg.range(),
                     ));
@@ -582,12 +593,12 @@ pub(crate) fn definition(
     // ANN101, ANN102
     if is_method && !visibility::is_staticmethod(&checker.ctx, cast::decorator_list(stmt)) {
         if let Some(arg) = args.posonlyargs.first().or_else(|| args.args.first()) {
-            if arg.node.annotation.is_none() {
+            if arg.annotation.is_none() {
                 if visibility::is_classmethod(&checker.ctx, cast::decorator_list(stmt)) {
                     if checker.settings.rules.enabled(Rule::MissingTypeCls) {
                         diagnostics.push(Diagnostic::new(
                             MissingTypeCls {
-                                name: arg.node.arg.to_string(),
+                                name: arg.arg.to_string(),
                             },
                             arg.range(),
                         ));
@@ -596,7 +607,7 @@ pub(crate) fn definition(
                     if checker.settings.rules.enabled(Rule::MissingTypeSelf) {
                         diagnostics.push(Diagnostic::new(
                             MissingTypeSelf {
-                                name: arg.node.arg.to_string(),
+                                name: arg.arg.to_string(),
                             },
                             arg.range(),
                         ));
@@ -612,7 +623,13 @@ pub(crate) fn definition(
     if let Some(expr) = &returns {
         has_typed_return = true;
         if checker.settings.rules.enabled(Rule::AnyType) {
-            check_dynamically_typed(checker, expr, || name.to_string(), &mut diagnostics);
+            check_dynamically_typed(
+                checker,
+                expr,
+                || name.to_string(),
+                &mut diagnostics,
+                is_overridden,
+            );
         }
     } else if !(
         // Allow omission of return annotation if the function only returns `None`
