@@ -7,8 +7,9 @@ pub mod settings;
 mod tests {
     use std::path::Path;
 
+    use crate::assert_messages;
     use anyhow::Result;
-    use insta::assert_yaml_snapshot;
+
     use test_case::test_case;
 
     use crate::registry::Rule;
@@ -17,6 +18,7 @@ mod tests {
 
     #[test_case(Rule::Assert, Path::new("S101.py"); "S101")]
     #[test_case(Rule::BadFilePermissions, Path::new("S103.py"); "S103")]
+    #[test_case(Rule::CallWithShellEqualsTrue, Path::new("S604.py"); "S604")]
     #[test_case(Rule::ExecBuiltin, Path::new("S102.py"); "S102")]
     #[test_case(Rule::HardcodedBindAllInterfaces, Path::new("S104.py"); "S104")]
     #[test_case(Rule::HardcodedPasswordDefault, Path::new("S107.py"); "S107")]
@@ -31,6 +33,11 @@ mod tests {
     #[test_case(Rule::RequestWithoutTimeout, Path::new("S113.py"); "S113")]
     #[test_case(Rule::SnmpInsecureVersion, Path::new("S508.py"); "S508")]
     #[test_case(Rule::SnmpWeakCryptography, Path::new("S509.py"); "S509")]
+    #[test_case(Rule::StartProcessWithAShell, Path::new("S605.py"); "S605")]
+    #[test_case(Rule::StartProcessWithNoShell, Path::new("S606.py"); "S606")]
+    #[test_case(Rule::StartProcessWithPartialPath, Path::new("S607.py"); "S607")]
+    #[test_case(Rule::SubprocessPopenWithShellEqualsTrue, Path::new("S602.py"); "S602")]
+    #[test_case(Rule::SubprocessWithoutShellEqualsTrue, Path::new("S603.py"); "S603")]
     #[test_case(Rule::SuspiciousPickleUsage, Path::new("S301.py"); "S301")]
     #[test_case(Rule::SuspiciousTelnetUsage, Path::new("S312.py"); "S312")]
     #[test_case(Rule::TryExceptContinue, Path::new("S112.py"); "S112")]
@@ -42,7 +49,7 @@ mod tests {
             Path::new("flake8_bandit").join(path).as_path(),
             &Settings::for_rule(rule_code),
         )?;
-        assert_yaml_snapshot!(snapshot, diagnostics);
+        assert_messages!(snapshot, diagnostics);
         Ok(())
     }
 
@@ -63,7 +70,7 @@ mod tests {
                 ..Settings::for_rule(Rule::HardcodedTempFile)
             },
         )?;
-        assert_yaml_snapshot!("S108_extend", diagnostics);
+        assert_messages!("S108_extend", diagnostics);
         Ok(())
     }
 
@@ -79,7 +86,7 @@ mod tests {
                 ..Settings::for_rule(Rule::TryExceptPass)
             },
         )?;
-        assert_yaml_snapshot!("S110_typed", diagnostics);
+        assert_messages!("S110_typed", diagnostics);
         Ok(())
     }
 }
