@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Expr, ExprKind};
+use rustpython_parser::ast::{self, Expr, Ranged};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -36,7 +36,7 @@ pub(crate) fn cached_instance_method(checker: &mut Checker, decorator_list: &[Ex
     for decorator in decorator_list {
         // TODO(charlie): This should take into account `classmethod-decorators` and
         // `staticmethod-decorators`.
-        if let ExprKind::Name(ast::ExprName { id, .. }) = &decorator.node {
+        if let Expr::Name(ast::ExprName { id, .. }) = decorator {
             if id == "classmethod" || id == "staticmethod" {
                 return;
             }
@@ -45,8 +45,8 @@ pub(crate) fn cached_instance_method(checker: &mut Checker, decorator_list: &[Ex
     for decorator in decorator_list {
         if is_cache_func(
             checker,
-            match &decorator.node {
-                ExprKind::Call(ast::ExprCall { func, .. }) => func,
+            match decorator {
+                Expr::Call(ast::ExprCall { func, .. }) => func,
                 _ => decorator,
             },
         ) {
