@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Comprehension, Expr, ExprKind, Stmt, StmtKind};
+use rustpython_parser::ast::{self, Comprehension, Expr, Ranged, Stmt};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -84,7 +84,7 @@ impl<'a> GroupNameFinder<'a> {
     }
 
     fn name_matches(&self, expr: &Expr) -> bool {
-        if let ExprKind::Name(ast::ExprName { id, .. }) = &expr.node {
+        if let Expr::Name(ast::ExprName { id, .. }) = expr {
             id == self.group_name
         } else {
             false
@@ -112,8 +112,8 @@ where
         if self.overridden {
             return;
         }
-        match &stmt.node {
-            StmtKind::For(ast::StmtFor {
+        match stmt {
+            Stmt::For(ast::StmtFor {
                 target, iter, body, ..
             }) => {
                 if self.name_matches(target) {
@@ -138,15 +138,20 @@ where
                     self.nested = false;
                 }
             }
-            StmtKind::While(ast::StmtWhile { body, .. }) => {
+            Stmt::While(ast::StmtWhile { body, .. }) => {
                 self.nested = true;
                 visitor::walk_body(self, body);
                 self.nested = false;
             }
-            StmtKind::If(ast::StmtIf { test, body, orelse }) => {
+            Stmt::If(ast::StmtIf {
+                test,
+                body,
+                orelse,
+                range: _,
+            }) => {
                 // Determine whether we're on an `if` arm (as opposed to an `elif`).
                 let is_if_arm = !self.parent_ifs.iter().any(|parent| {
-                    if let StmtKind::If(ast::StmtIf { orelse, .. }) = &parent.node {
+                    if let Stmt::If(ast::StmtIf { orelse, .. }) = parent {
                         orelse.len() == 1 && &orelse[0] == stmt
                     } else {
                         false
@@ -166,12 +171,12 @@ where
 
                 let has_else = orelse
                     .first()
-                    .map_or(false, |expr| !matches!(expr.node, StmtKind::If(_)));
+                    .map_or(false, |expr| !matches!(expr, Stmt::If(_)));
 
                 self.parent_ifs.push(stmt);
                 if has_else {
-                    // There's no `StmtKind::Else`; instead, the `else` contents are directly on
-                    // the `orelse` of the `StmtKind::If` node. We want to add a new counter for
+                    // There's no `Stmt::Else`; instead, the `else` contents are directly on
+                    // the `orelse` of the `Stmt::If` node. We want to add a new counter for
                     // the `orelse` branch, but first, we need to visit the `if` body manually.
                     self.visit_expr(test);
                     self.visit_body(body);
@@ -193,7 +198,11 @@ where
                     }
                 }
             }
-            StmtKind::Match(ast::StmtMatch { subject, cases }) => {
+            Stmt::Match(ast::StmtMatch {
+                subject,
+                cases,
+                range: _,
+            }) => {
                 self.counter_stack.push(Vec::with_capacity(cases.len()));
                 self.visit_expr(subject);
                 for match_case in cases {
@@ -207,14 +216,14 @@ where
                     self.increment_usage_count(max_count);
                 }
             }
-            StmtKind::Assign(ast::StmtAssign { targets, value, .. }) => {
+            Stmt::Assign(ast::StmtAssign { targets, value, .. }) => {
                 if targets.iter().any(|target| self.name_matches(target)) {
                     self.overridden = true;
                 } else {
                     self.visit_expr(value);
                 }
             }
-            StmtKind::AnnAssign(ast::StmtAnnAssign { target, value, .. }) => {
+            Stmt::AnnAssign(ast::StmtAnnAssign { target, value, .. }) => {
                 if self.name_matches(target) {
                     self.overridden = true;
                 } else if let Some(expr) = value {
@@ -241,7 +250,7 @@ where
     }
 
     fn visit_expr(&mut self, expr: &'a Expr) {
-        if let ExprKind::NamedExpr(ast::ExprNamedExpr { target, .. }) = &expr.node {
+        if let Expr::NamedExpr(ast::ExprNamedExpr { target, .. }) = expr {
             if self.name_matches(target) {
                 self.overridden = true;
             }
@@ -250,9 +259,17 @@ where
             return;
         }
 
-        match &expr.node {
-            ExprKind::ListComp(ast::ExprListComp { elt, generators })
-            | ExprKind::SetComp(ast::ExprSetComp { elt, generators }) => {
+        match expr {
+            Expr::ListComp(ast::ExprListComp {
+                elt,
+                generators,
+                range: _,
+            })
+            | Expr::SetComp(ast::ExprSetComp {
+                elt,
+                generators,
+                range: _,
+            }) => {
                 for comprehension in generators {
                     self.visit_comprehension(comprehension);
                 }
@@ -262,10 +279,11 @@ where
                     self.nested = false;
                 }
             }
-            ExprKind::DictComp(ast::ExprDictComp {
+            Expr::DictComp(ast::ExprDictComp {
                 key,
                 value,
                 generators,
+                range: _,
             }) => {
                 for comprehension in generators {
                     self.visit_comprehension(comprehension);
@@ -308,10 +326,10 @@ pub(crate) fn reuse_of_groupby_generator(
     body: &[Stmt],
     iter: &Expr,
 ) {
-    let ExprKind::Call(ast::ExprCall { func, .. }) = &iter.node else {
+    let Expr::Call(ast::ExprCall { func, .. }) = &iter else {
         return;
     };
-    let ExprKind::Tuple(ast::ExprTuple { elts, .. }) = &target.node else {
+    let Expr::Tuple(ast::ExprTuple { elts, .. }) = target else {
         // Ignore any `groupby()` invocation that isn't unpacked
         return;
     };
@@ -319,7 +337,7 @@ pub(crate) fn reuse_of_groupby_generator(
         return;
     }
     // We have an invocation of groupby which is a simple unpacking
-    let ExprKind::Name(ast::ExprName { id: group_name, .. }) = &elts[1].node else {
+    let Expr::Name(ast::ExprName { id: group_name, .. }) = &elts[1] else {
         return;
     };
     // Check if the function call is `itertools.groupby`
