@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Expr, ExprKind, Keyword};
+use rustpython_parser::ast::{self, Expr, Keyword, Ranged};
 
 use crate::checkers::ast::Checker;
 use ruff_diagnostics::{Diagnostic, Violation};
@@ -21,16 +21,12 @@ pub(crate) fn zip_without_explicit_strict(
     func: &Expr,
     kwargs: &[Keyword],
 ) {
-    if let ExprKind::Name(ast::ExprName { id, .. }) = &func.node {
+    if let Expr::Name(ast::ExprName { id, .. }) = func {
         if id == "zip"
             && checker.ctx.is_builtin("zip")
-            && !kwargs.iter().any(|keyword| {
-                keyword
-                    .node
-                    .arg
-                    .as_ref()
-                    .map_or(false, |name| name == "strict")
-            })
+            && !kwargs
+                .iter()
+                .any(|keyword| keyword.arg.as_ref().map_or(false, |name| name == "strict"))
         {
             checker
                 .diagnostics
