@@ -7,8 +7,9 @@ use libcst_native::{
     ParenthesizedWhitespace, RightCurlyBrace, RightParen, RightSquareBracket, Set, SetComp,
     SimpleString, SimpleWhitespace, TrailingWhitespace, Tuple,
 };
+use rustpython_parser::ast::Ranged;
 
-use ruff_diagnostics::Edit;
+use ruff_diagnostics::{Edit, Fix};
 use ruff_python_ast::source_code::{Locator, Stylist};
 
 use crate::cst::matchers::{match_expr, match_module};
@@ -115,10 +116,8 @@ pub(crate) fn fix_unnecessary_generator_set(
 
     // If the expression is embedded in an f-string, surround it with spaces to avoid
     // syntax errors.
-    if let Some(parent_element) = parent {
-        if let &rustpython_parser::ast::ExprKind::FormattedValue(_) = &parent_element.node {
-            content = format!(" {content} ");
-        }
+    if let Some(rustpython_parser::ast::Expr::FormattedValue(_)) = parent {
+        content = format!(" {content} ");
     }
 
     Ok(Edit::range_replacement(content, expr.range()))
@@ -185,10 +184,8 @@ pub(crate) fn fix_unnecessary_generator_dict(
 
     // If the expression is embedded in an f-string, surround it with spaces to avoid
     // syntax errors.
-    if let Some(parent_element) = parent {
-        if let &rustpython_parser::ast::ExprKind::FormattedValue(_) = &parent_element.node {
-            content = format!(" {content} ");
-        }
+    if let Some(rustpython_parser::ast::Expr::FormattedValue(_)) = parent {
+        content = format!(" {content} ");
     }
 
     Ok(Edit::range_replacement(content, expr.range()))
@@ -1100,10 +1097,8 @@ pub(crate) fn fix_unnecessary_map(
         // If the expression is embedded in an f-string, surround it with spaces to avoid
         // syntax errors.
         if kind == "set" || kind == "dict" {
-            if let Some(parent_element) = parent {
-                if let &rustpython_parser::ast::ExprKind::FormattedValue(_) = &parent_element.node {
-                    content = format!(" {content} ");
-                }
+            if let Some(rustpython_parser::ast::Expr::FormattedValue(_)) = parent {
+                content = format!(" {content} ");
             }
         }
 
@@ -1142,7 +1137,7 @@ pub(crate) fn fix_unnecessary_comprehension_any_all(
     locator: &Locator,
     stylist: &Stylist,
     expr: &rustpython_parser::ast::Expr,
-) -> Result<Edit> {
+) -> Result<Fix> {
     // Expr(ListComp) -> Expr(GeneratorExp)
     let module_text = locator.slice(expr.range());
     let mut tree = match_module(module_text)?;
@@ -1312,5 +1307,8 @@ pub(crate) fn fix_unnecessary_comprehension_any_all(
     };
     tree.codegen(&mut state);
 
-    Ok(Edit::range_replacement(state.to_string(), expr.range()))
+    Ok(Fix::suggested(Edit::range_replacement(
+        state.to_string(),
+        expr.range(),
+    )))
 }
