@@ -1,7 +1,7 @@
-use rustpython_parser::ast::{self, Expr, ExprKind, Keyword};
+use rustpython_parser::ast::{self, Expr, Keyword};
 
 pub(crate) fn expr_name(func: &Expr) -> Option<&str> {
-    if let ExprKind::Name(ast::ExprName { id, .. }) = &func.node {
+    if let Expr::Name(ast::ExprName { id, .. }) = func {
         Some(id)
     } else {
         None
@@ -13,7 +13,7 @@ pub(crate) fn exactly_one_argument_with_matching_function<'a>(
     func: &Expr,
     args: &'a [Expr],
     keywords: &[Keyword],
-) -> Option<&'a ExprKind> {
+) -> Option<&'a Expr> {
     if !keywords.is_empty() {
         return None;
     }
@@ -23,16 +23,16 @@ pub(crate) fn exactly_one_argument_with_matching_function<'a>(
     if expr_name(func)? != name {
         return None;
     }
-    Some(&args[0].node)
+    Some(&args[0])
 }
 
 pub(crate) fn first_argument_with_matching_function<'a>(
     name: &str,
     func: &Expr,
     args: &'a [Expr],
-) -> Option<&'a ExprKind> {
+) -> Option<&'a Expr> {
     if expr_name(func)? == name {
-        Some(&args.first()?.node)
+        Some(args.first()?)
     } else {
         None
     }
