@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Constant, Expr, ExprKind, Stmt, StmtKind};
+use rustpython_parser::ast::{self, Constant, Expr, Ranged, Stmt};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -56,27 +56,27 @@ pub(crate) fn all_with_model_form(
         return None;
     }
     for element in body.iter() {
-        let StmtKind::ClassDef(ast::StmtClassDef { name, body, .. }) = &element.node else {
+        let Stmt::ClassDef(ast::StmtClassDef { name, body, .. }) = element else {
             continue;
         };
         if name != "Meta" {
             continue;
         }
         for element in body.iter() {
-            let StmtKind::Assign(ast::StmtAssign { targets, value, .. }) = &element.node else {
+            let Stmt::Assign(ast::StmtAssign { targets, value, .. }) = element else {
                 continue;
             };
             for target in targets.iter() {
-                let ExprKind::Name(ast::ExprName { id, .. }) = &target.node else {
+                let Expr::Name(ast::ExprName { id, .. }) = target else {
                     continue;
                 };
                 if id != "fields" {
                     continue;
                 }
-                let ExprKind::Constant(ast::ExprConstant { value, .. }) = &value.node else {
+                let Expr::Constant(ast::ExprConstant { value, .. }) = value.as_ref() else {
                     continue;
                 };
-                match &value {
+                match value {
                     Constant::Str(s) => {
                         if s == "__all__" {
                             return Some(Diagnostic::new(DjangoAllWithModelForm, element.range()));
