@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Constant, Expr, ExprKind, Stmt, StmtKind};
+use rustpython_parser::ast::{self, Constant, Expr, Ranged, Stmt};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -68,8 +68,8 @@ pub(crate) fn model_without_dunder_str(
 }
 
 fn has_dunder_method(body: &[Stmt]) -> bool {
-    body.iter().any(|val| match &val.node {
-        StmtKind::FunctionDef(ast::StmtFunctionDef { name, .. }) => {
+    body.iter().any(|val| match val {
+        Stmt::FunctionDef(ast::StmtFunctionDef { name, .. }) => {
             if name == "__str__" {
                 return true;
             }
@@ -94,24 +94,24 @@ fn checker_applies(checker: &Checker, bases: &[Expr], body: &[Stmt]) -> bool {
 /// Check if class is abstract, in terms of Django model inheritance.
 fn is_model_abstract(body: &[Stmt]) -> bool {
     for element in body.iter() {
-        let StmtKind::ClassDef(ast::StmtClassDef {name, body, ..}) = &element.node else {
+        let Stmt::ClassDef(ast::StmtClassDef {name, body, ..}) = element else {
             continue
         };
         if name != "Meta" {
             continue;
         }
         for element in body.iter() {
-            let StmtKind::Assign(ast::StmtAssign {targets, value, ..}) = &element.node else {
+            let Stmt::Assign(ast::StmtAssign {targets, value, ..}) = element else {
                 continue;
             };
             for target in targets.iter() {
-                let ExprKind::Name(ast::ExprName {id , ..}) = &target.node else {
+                let Expr::Name(ast::ExprName {id , ..}) = target else {
                     continue;
                 };
                 if id != "abstract" {
                     continue;
                 }
-                let ExprKind::Constant(ast::ExprConstant{value: Constant::Bool(true), ..}) = &value.node else {
+                let Expr::Constant(ast::ExprConstant{value: Constant::Bool(true), ..}) = value.as_ref() else {
                     continue;
                 };
                 return true;
