@@ -1,9 +1,10 @@
-use rustpython_parser::ast::{self, Constant, Expr, ExprContext, ExprKind, Stmt, StmtKind};
+use ruff_text_size::TextRange;
+use rustpython_parser::ast::{self, Constant, Expr, ExprContext, Ranged, Stmt};
 
 use ruff_diagnostics::{AutofixKind, Diagnostic, Edit, Fix, Violation};
 use ruff_macros::{derive_message_formats, violation};
-use ruff_python_ast::helpers::{create_expr, create_stmt, unparse_stmt};
-use ruff_python_ast::source_code::Stylist;
+
+use ruff_python_ast::source_code::{Generator, Stylist};
 use ruff_python_ast::whitespace;
 
 use crate::checkers::ast::Checker;
@@ -182,18 +183,25 @@ impl Violation for DotFormatInException {
 /// 1. Insert the exception argument into a variable assignment before the
 ///   `raise` statement. The variable name is `msg`.
 /// 2. Replace the exception argument with the variable name.
-fn generate_fix(stylist: &Stylist, stmt: &Stmt, exc_arg: &Expr, indentation: &str) -> Fix {
-    let assignment = unparse_stmt(
-        &create_stmt(StmtKind::Assign(ast::StmtAssign {
-            targets: vec![create_expr(ExprKind::Name(ast::ExprName {
-                id: "msg".into(),
-                ctx: ExprContext::Store,
-            }))],
-            value: Box::new(exc_arg.clone()),
-            type_comment: None,
-        })),
-        stylist,
-    );
+fn generate_fix(
+    stmt: &Stmt,
+    exc_arg: &Expr,
+    indentation: &str,
+    stylist: &Stylist,
+    generator: Generator,
+) -> Fix {
+    let node = Expr::Name(ast::ExprName {
+        id: "msg".into(),
+        ctx: ExprContext::Store,
+        range: TextRange::default(),
+    });
+    let node1 = Stmt::Assign(ast::StmtAssign {
+        targets: vec![node],
+        value: Box::new(exc_arg.clone()),
+        type_comment: None,
+        range: TextRange::default(),
+    });
+    let assignment = generator.stmt(&node1);
     #[allow(deprecated)]
     Fix::unspecified_edits(
         Edit::insertion(
@@ -214,11 +222,11 @@ fn generate_fix(stylist: &Stylist, stmt: &Stmt, exc_arg: &Expr, indentation: &st
 
 /// EM101, EM102, EM103
 pub(crate) fn string_in_exception(checker: &mut Checker, stmt: &Stmt, exc: &Expr) {
-    if let ExprKind::Call(ast::ExprCall { args, .. }) = &exc.node {
+    if let Expr::Call(ast::ExprCall { args, .. }) = exc {
         if let Some(first) = args.first() {
-            match &first.node {
-                // Check for string literals
-                ExprKind::Constant(ast::ExprConstant {
+            match first {
+                // Check for string literals.
+                Expr::Constant(ast::ExprConstant {
                     value: Constant::Str(string),
                     ..
                 }) => {
@@ -237,10 +245,11 @@ pub(crate) fn string_in_exception(checker: &mut Checker, stmt: &Stmt, exc: &Expr
                             if let Some(indentation) = indentation {
                                 if checker.patch(diagnostic.kind.rule()) {
                                     diagnostic.set_fix(generate_fix(
-                                        checker.stylist,
                                         stmt,
                                         first,
                                         indentation,
+                                        checker.stylist,
+                                        checker.generator(),
                                     ));
                                 }
                             }
@@ -248,8 +257,8 @@ pub(crate) fn string_in_exception(checker: &mut Checker, stmt: &Stmt, exc: &Expr
                         }
                     }
                 }
-                // Check for f-strings
-                ExprKind::JoinedStr(_) => {
+                // Check for f-strings.
+                Expr::JoinedStr(_) => {
                     if checker.settings.rules.enabled(Rule::FStringInException) {
                         let indentation = whitespace::indentation(checker.locator, stmt).and_then(
                             |indentation| {
@@ -264,23 +273,24 @@ pub(crate) fn string_in_exception(checker: &mut Checker, stmt: &Stmt, exc: &Expr
                         if let Some(indentation) = indentation {
                             if checker.patch(diagnostic.kind.rule()) {
                                 diagnostic.set_fix(generate_fix(
-                                    checker.stylist,
                                     stmt,
                                     first,
                                     indentation,
+                                    checker.stylist,
+                                    checker.generator(),
                                 ));
                             }
                         }
                         checker.diagnostics.push(diagnostic);
                     }
                 }
-                // Check for .format() calls
-                ExprKind::Call(ast::ExprCall { func, .. }) => {
+                // Check for .format() calls.
+                Expr::Call(ast::ExprCall { func, .. }) => {
                     if checker.settings.rules.enabled(Rule::DotFormatInException) {
-                        if let ExprKind::Attribute(ast::ExprAttribute { value, attr, .. }) =
-                            &func.node
+                        if let Expr::Attribute(ast::ExprAttribute { value, attr, .. }) =
+                            func.as_ref()
                         {
-                            if attr == "format" && matches!(value.node, ExprKind::Constant(_)) {
+                            if attr == "format" && value.is_constant_expr() {
                                 let indentation = whitespace::indentation(checker.locator, stmt)
                                     .and_then(|indentation| {
                                         if checker.ctx.find_binding("msg").is_none() {
@@ -294,10 +304,11 @@ pub(crate) fn string_in_exception(checker: &mut Checker, stmt: &Stmt, exc: &Expr
                                 if let Some(indentation) = indentation {
                                     if checker.patch(diagnostic.kind.rule()) {
                                         diagnostic.set_fix(generate_fix(
-                                            checker.stylist,
                                             stmt,
                                             first,
                                             indentation,
+                                            checker.stylist,
+                                            checker.generator(),
                                         ));
                                     }
                                 }
