@@ -7,12 +7,12 @@ mod tests {
     use std::path::Path;
 
     use anyhow::Result;
-    use insta::assert_yaml_snapshot;
+
     use test_case::test_case;
 
     use crate::registry::Rule;
-    use crate::settings;
     use crate::test::test_path;
+    use crate::{assert_messages, settings};
 
     #[test_case(Rule::FStringInGetTextFuncCall,Path::new("INT001.py"); "INT001")]
     #[test_case(Rule::FormatInGetTextFuncCall, Path::new("INT002.py"); "INT002")]
@@ -23,7 +23,7 @@ mod tests {
             Path::new("flake8_gettext").join(path).as_path(),
             &settings::Settings::for_rule(rule_code),
         )?;
-        assert_yaml_snapshot!(snapshot, diagnostics);
+        assert_messages!(snapshot, diagnostics);
         Ok(())
     }
 }
