@@ -1,8 +1,10 @@
 use serde::{Deserialize, Serialize};
 
-use ruff_macros::{CacheKey, ConfigurationOptions};
+use ruff_macros::{CacheKey, CombineOptions, ConfigurationOptions};
 
-#[derive(Debug, PartialEq, Eq, Serialize, Deserialize, Default, ConfigurationOptions)]
+#[derive(
+    Debug, PartialEq, Eq, Serialize, Deserialize, Default, ConfigurationOptions, CombineOptions,
+)]
 #[serde(
     deny_unknown_fields,
     rename_all = "kebab-case",
@@ -22,10 +24,9 @@ pub struct Options {
         value_type = "list[str]",
         example = r#"extend-function-names = ["ugettetxt"]"#
     )]
-    #[serde(default)]
     /// Additional function names to consider as internationalization calls, in addition to those
     /// included in `function-names`.
-    pub extend_function_names: Vec<String>,
+    pub extend_function_names: Option<Vec<String>>,
 }
 
 #[derive(Debug, CacheKey)]
@@ -34,10 +35,11 @@ pub struct Settings {
 }
 
 fn default_func_names() -> Vec<String> {
-    ["_", "gettext", "ngettext"]
-        .iter()
-        .map(std::string::ToString::to_string)
-        .collect()
+    vec![
+        "_".to_string(),
+        "gettext".to_string(),
+        "ngettext".to_string(),
+    ]
 }
 
 impl Default for Settings {
@@ -55,7 +57,12 @@ impl From<Options> for Settings {
                 .function_names
                 .unwrap_or_else(default_func_names)
                 .into_iter()
-                .chain(options.extend_function_names)
+                .chain(
+                    options
+                        .extend_function_names
+                        .unwrap_or_default()
+                        .into_iter(),
+                )
                 .collect(),
         }
     }
@@ -65,7 +72,7 @@ impl From<Settings> for Options {
     fn from(settings: Settings) -> Self {
         Self {
             function_names: Some(settings.functions_names),
-            extend_function_names: vec![],
+            extend_function_names: Some(Vec::new()),
         }
     }
 }
