@@ -13,38 +13,40 @@ mod tests {
     use crate::test::test_path;
     use crate::{assert_messages, settings};
 
-    #[test_case(Rule::UnprefixedTypeParam, Path::new("PYI001.py"))]
-    #[test_case(Rule::UnprefixedTypeParam, Path::new("PYI001.pyi"))]
-    #[test_case(Rule::BadVersionInfoComparison, Path::new("PYI006.py"))]
-    #[test_case(Rule::BadVersionInfoComparison, Path::new("PYI006.pyi"))]
-    #[test_case(Rule::UnrecognizedPlatformCheck, Path::new("PYI007.py"))]
-    #[test_case(Rule::UnrecognizedPlatformCheck, Path::new("PYI007.pyi"))]
-    #[test_case(Rule::UnrecognizedPlatformName, Path::new("PYI008.py"))]
-    #[test_case(Rule::UnrecognizedPlatformName, Path::new("PYI008.pyi"))]
-    #[test_case(Rule::PassStatementStubBody, Path::new("PYI009.py"))]
-    #[test_case(Rule::PassStatementStubBody, Path::new("PYI009.pyi"))]
-    #[test_case(Rule::NonEmptyStubBody, Path::new("PYI010.py"))]
-    #[test_case(Rule::NonEmptyStubBody, Path::new("PYI010.pyi"))]
-    #[test_case(Rule::TypedArgumentDefaultInStub, Path::new("PYI011.py"))]
-    #[test_case(Rule::TypedArgumentDefaultInStub, Path::new("PYI011.pyi"))]
-    #[test_case(Rule::PassInClassBody, Path::new("PYI012.py"))]
-    #[test_case(Rule::PassInClassBody, Path::new("PYI012.pyi"))]
     #[test_case(Rule::ArgumentDefaultInStub, Path::new("PYI014.py"))]
     #[test_case(Rule::ArgumentDefaultInStub, Path::new("PYI014.pyi"))]
     #[test_case(Rule::AssignmentDefaultInStub, Path::new("PYI015.py"))]
     #[test_case(Rule::AssignmentDefaultInStub, Path::new("PYI015.pyi"))]
-    #[test_case(Rule::DuplicateUnionMember, Path::new("PYI016.py"))]
-    #[test_case(Rule::DuplicateUnionMember, Path::new("PYI016.pyi"))]
-    #[test_case(Rule::QuotedAnnotationInStub, Path::new("PYI020.py"))]
-    #[test_case(Rule::QuotedAnnotationInStub, Path::new("PYI020.pyi"))]
+    #[test_case(Rule::BadVersionInfoComparison, Path::new("PYI006.py"))]
+    #[test_case(Rule::BadVersionInfoComparison, Path::new("PYI006.pyi"))]
     #[test_case(Rule::DocstringInStub, Path::new("PYI021.py"))]
     #[test_case(Rule::DocstringInStub, Path::new("PYI021.pyi"))]
-    #[test_case(Rule::TypeCommentInStub, Path::new("PYI033.py"))]
-    #[test_case(Rule::TypeCommentInStub, Path::new("PYI033.pyi"))]
+    #[test_case(Rule::DuplicateUnionMember, Path::new("PYI016.py"))]
+    #[test_case(Rule::DuplicateUnionMember, Path::new("PYI016.pyi"))]
+    #[test_case(Rule::NonEmptyStubBody, Path::new("PYI010.py"))]
+    #[test_case(Rule::NonEmptyStubBody, Path::new("PYI010.pyi"))]
+    #[test_case(Rule::PassInClassBody, Path::new("PYI012.py"))]
+    #[test_case(Rule::PassInClassBody, Path::new("PYI012.pyi"))]
+    #[test_case(Rule::PassStatementStubBody, Path::new("PYI009.py"))]
+    #[test_case(Rule::PassStatementStubBody, Path::new("PYI009.pyi"))]
+    #[test_case(Rule::QuotedAnnotationInStub, Path::new("PYI020.py"))]
+    #[test_case(Rule::QuotedAnnotationInStub, Path::new("PYI020.pyi"))]
     #[test_case(Rule::SnakeCaseTypeAlias, Path::new("PYI042.py"))]
     #[test_case(Rule::SnakeCaseTypeAlias, Path::new("PYI042.pyi"))]
     #[test_case(Rule::TSuffixedTypeAlias, Path::new("PYI043.py"))]
     #[test_case(Rule::TSuffixedTypeAlias, Path::new("PYI043.pyi"))]
+    #[test_case(Rule::TypeCommentInStub, Path::new("PYI033.py"))]
+    #[test_case(Rule::TypeCommentInStub, Path::new("PYI033.pyi"))]
+    #[test_case(Rule::TypedArgumentDefaultInStub, Path::new("PYI011.py"))]
+    #[test_case(Rule::TypedArgumentDefaultInStub, Path::new("PYI011.pyi"))]
+    #[test_case(Rule::UnannotatedAssignmentInStub, Path::new("PYI052.py"))]
+    #[test_case(Rule::UnannotatedAssignmentInStub, Path::new("PYI052.pyi"))]
+    #[test_case(Rule::UnprefixedTypeParam, Path::new("PYI001.py"))]
+    #[test_case(Rule::UnprefixedTypeParam, Path::new("PYI001.pyi"))]
+    #[test_case(Rule::UnrecognizedPlatformCheck, Path::new("PYI007.py"))]
+    #[test_case(Rule::UnrecognizedPlatformCheck, Path::new("PYI007.pyi"))]
+    #[test_case(Rule::UnrecognizedPlatformName, Path::new("PYI008.py"))]
+    #[test_case(Rule::UnrecognizedPlatformName, Path::new("PYI008.pyi"))]
     fn rules(rule_code: Rule, path: &Path) -> Result<()> {
         let snapshot = format!("{}_{}", rule_code.noqa_code(), path.to_string_lossy());
         let diagnostics = test_path(
