@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Constant, ExprKind, Stmt, StmtKind};
+use rustpython_parser::ast::{self, Constant, Expr, Ranged, Stmt};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -20,8 +20,8 @@ pub(crate) fn non_empty_stub_body(checker: &mut Checker, body: &[Stmt]) {
     if body.len() != 1 {
         return;
     }
-    if let StmtKind::Expr(ast::StmtExpr { value }) = &body[0].node {
-        if let ExprKind::Constant(ast::ExprConstant { value, .. }) = &value.node {
+    if let Stmt::Expr(ast::StmtExpr { value, range: _ }) = &body[0] {
+        if let Expr::Constant(ast::ExprConstant { value, .. }) = value.as_ref() {
             if matches!(value, Constant::Ellipsis | Constant::Str(_)) {
                 return;
             }
