@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Constant, Expr, ExprKind, Keyword};
+use rustpython_parser::ast::{self, Constant, Expr, Keyword};
 
 use ruff_python_ast::call_path::{collect_call_path, CallPath};
 use ruff_python_ast::helpers::map_callable;
@@ -48,10 +48,10 @@ pub(super) fn is_pytest_parametrize(context: &Context, decorator: &Expr) -> bool
 }
 
 pub(super) fn keyword_is_literal(kw: &Keyword, literal: &str) -> bool {
-    if let ExprKind::Constant(ast::ExprConstant {
+    if let Expr::Constant(ast::ExprConstant {
         value: Constant::Str(string),
         ..
-    }) = &kw.node.value.node
+    }) = &kw.value
     {
         string == literal
     } else {
@@ -60,13 +60,13 @@ pub(super) fn keyword_is_literal(kw: &Keyword, literal: &str) -> bool {
 }
 
 pub(super) fn is_empty_or_null_string(expr: &Expr) -> bool {
-    match &expr.node {
-        ExprKind::Constant(ast::ExprConstant {
+    match expr {
+        Expr::Constant(ast::ExprConstant {
             value: Constant::Str(string),
             ..
         }) => string.is_empty(),
-        ExprKind::Constant(constant) if constant.value.is_none() => true,
-        ExprKind::JoinedStr(ast::ExprJoinedStr { values }) => {
+        Expr::Constant(constant) if constant.value.is_none() => true,
+        Expr::JoinedStr(ast::ExprJoinedStr { values, range: _ }) => {
             values.iter().all(is_empty_or_null_string)
         }
         _ => false,
