@@ -2,13 +2,13 @@ use ruff_text_size::TextRange;
 use rustpython_parser::lexer::LexResult;
 use rustpython_parser::Tok;
 
-use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Edit};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Edit, Fix};
 use ruff_macros::{derive_message_formats, violation};
 use ruff_python_ast::source_code::Locator;
 
 use crate::lex::docstring_detection::StateMachine;
 use crate::registry::Rule;
-use crate::settings::{flags, Settings};
+use crate::settings::Settings;
 
 use super::settings::Quote;
 
@@ -34,7 +34,7 @@ use super::settings::Quote;
 /// ```
 #[violation]
 pub struct BadQuotesInlineString {
-    pub quote: Quote,
+    quote: Quote,
 }
 
 impl AlwaysAutofixableViolation for BadQuotesInlineString {
@@ -83,7 +83,7 @@ impl AlwaysAutofixableViolation for BadQuotesInlineString {
 /// ```
 #[violation]
 pub struct BadQuotesMultilineString {
-    pub quote: Quote,
+    quote: Quote,
 }
 
 impl AlwaysAutofixableViolation for BadQuotesMultilineString {
@@ -131,7 +131,7 @@ impl AlwaysAutofixableViolation for BadQuotesMultilineString {
 /// ```
 #[violation]
 pub struct BadQuotesDocstring {
-    pub quote: Quote,
+    quote: Quote,
 }
 
 impl AlwaysAutofixableViolation for BadQuotesDocstring {
@@ -255,12 +255,7 @@ impl<'a> From<&'a str> for Trivia<'a> {
 }
 
 /// Q003
-fn docstring(
-    locator: &Locator,
-    range: TextRange,
-    settings: &Settings,
-    autofix: flags::Autofix,
-) -> Option<Diagnostic> {
+fn docstring(locator: &Locator, range: TextRange, settings: &Settings) -> Option<Diagnostic> {
     let quotes_settings = &settings.flake8_quotes;
 
     let text = locator.slice(range);
@@ -279,7 +274,7 @@ fn docstring(
         },
         range,
     );
-    if autofix.into() && settings.rules.should_fix(Rule::BadQuotesDocstring) {
+    if settings.rules.should_fix(Rule::BadQuotesDocstring) {
         let quote_count = if trivia.is_multiline { 3 } else { 1 };
         let string_contents = &trivia.raw_text[quote_count..trivia.raw_text.len() - quote_count];
         let quote = good_docstring(quotes_settings.docstring_quotes).repeat(quote_count);
@@ -289,18 +284,17 @@ fn docstring(
         fixed_contents.push_str(&quote);
         fixed_contents.push_str(string_contents);
         fixed_contents.push_str(&quote);
-        diagnostic.set_fix(Edit::range_replacement(fixed_contents, range));
+        #[allow(deprecated)]
+        diagnostic.set_fix(Fix::unspecified(Edit::range_replacement(
+            fixed_contents,
+            range,
+        )));
     }
     Some(diagnostic)
 }
 
 /// Q001, Q002
-fn strings(
-    locator: &Locator,
-    sequence: &[TextRange],
-    settings: &Settings,
-    autofix: flags::Autofix,
-) -> Vec<Diagnostic> {
+fn strings(locator: &Locator, sequence: &[TextRange], settings: &Settings) -> Vec<Diagnostic> {
     let mut diagnostics = vec![];
 
     let quotes_settings = &settings.flake8_quotes;
@@ -354,7 +348,7 @@ fn strings(
                 *range,
             );
 
-            if autofix.into() && settings.rules.should_fix(Rule::BadQuotesMultilineString) {
+            if settings.rules.should_fix(Rule::BadQuotesMultilineString) {
                 let string_contents = &trivia.raw_text[3..trivia.raw_text.len() - 3];
                 let quote = good_multiline(quotes_settings.multiline_quotes);
                 let mut fixed_contents = String::with_capacity(
@@ -364,7 +358,11 @@ fn strings(
                 fixed_contents.push_str(quote);
                 fixed_contents.push_str(string_contents);
                 fixed_contents.push_str(quote);
-                diagnostic.set_fix(Edit::range_replacement(fixed_contents, *range));
+                #[allow(deprecated)]
+                diagnostic.set_fix(Fix::unspecified(Edit::range_replacement(
+                    fixed_contents,
+                    *range,
+                )));
             }
             diagnostics.push(diagnostic);
         } else {
@@ -383,7 +381,7 @@ fn strings(
                     && !string_contents.contains(bad_single(quotes_settings.inline_quotes))
                 {
                     let mut diagnostic = Diagnostic::new(AvoidableEscapedQuote, *range);
-                    if autofix.into() && settings.rules.should_fix(Rule::AvoidableEscapedQuote) {
+                    if settings.rules.should_fix(Rule::AvoidableEscapedQuote) {
                         let quote = bad_single(quotes_settings.inline_quotes);
 
                         let mut fixed_contents =
@@ -427,7 +425,11 @@ fn strings(
 
                         fixed_contents.push(quote);
 
-                        diagnostic.set_fix(Edit::range_replacement(fixed_contents, *range));
+                        #[allow(deprecated)]
+                        diagnostic.set_fix(Fix::unspecified(Edit::range_replacement(
+                            fixed_contents,
+                            *range,
+                        )));
                     }
                     diagnostics.push(diagnostic);
                 }
@@ -442,7 +444,7 @@ fn strings(
                     },
                     *range,
                 );
-                if autofix.into() && settings.rules.should_fix(Rule::BadQuotesInlineString) {
+                if settings.rules.should_fix(Rule::BadQuotesInlineString) {
                     let quote = good_single(quotes_settings.inline_quotes);
                     let mut fixed_contents =
                         String::with_capacity(trivia.prefix.len() + string_contents.len() + 2);
@@ -450,7 +452,11 @@ fn strings(
                     fixed_contents.push(quote);
                     fixed_contents.push_str(string_contents);
                     fixed_contents.push(quote);
-                    diagnostic.set_fix(Edit::range_replacement(fixed_contents, *range));
+                    #[allow(deprecated)]
+                    diagnostic.set_fix(Fix::unspecified(Edit::range_replacement(
+                        fixed_contents,
+                        *range,
+                    )));
                 }
                 diagnostics.push(diagnostic);
             }
@@ -461,11 +467,10 @@ fn strings(
 }
 
 /// Generate `flake8-quote` diagnostics from a token stream.
-pub fn from_tokens(
+pub(crate) fn from_tokens(
     lxr: &[LexResult],
     locator: &Locator,
     settings: &Settings,
-    autofix: flags::Autofix,
 ) -> Vec<Diagnostic> {
     let mut diagnostics = vec![];
 
@@ -480,10 +485,10 @@ pub fn from_tokens(
         // docstring, then move on.
         if is_docstring {
             if !sequence.is_empty() {
-                diagnostics.extend(strings(locator, &sequence, settings, autofix));
+                diagnostics.extend(strings(locator, &sequence, settings));
                 sequence.clear();
             }
-            if let Some(diagnostic) = docstring(locator, range, settings, autofix) {
+            if let Some(diagnostic) = docstring(locator, range, settings) {
                 diagnostics.push(diagnostic);
             }
         } else {
@@ -493,7 +498,7 @@ pub fn from_tokens(
             } else if !matches!(tok, Tok::Comment(..) | Tok::NonLogicalNewline) {
                 // Otherwise, consume the sequence.
                 if !sequence.is_empty() {
-                    diagnostics.extend(strings(locator, &sequence, settings, autofix));
+                    diagnostics.extend(strings(locator, &sequence, settings));
                     sequence.clear();
                 }
             }
@@ -502,7 +507,7 @@ pub fn from_tokens(
 
     // If we have an unterminated sequence, consume it.
     if !sequence.is_empty() {
-        diagnostics.extend(strings(locator, &sequence, settings, autofix));
+        diagnostics.extend(strings(locator, &sequence, settings));
         sequence.clear();
     }
 
