@@ -3,13 +3,15 @@
 use rustc_hash::FxHashMap;
 use serde::{Deserialize, Serialize};
 
-use ruff_macros::ConfigurationOptions;
+use ruff_macros::{CombineOptions, ConfigurationOptions};
 
 use super::banned_api::ApiBan;
 use super::relative_imports::Strictness;
 use super::Settings;
 
-#[derive(Debug, PartialEq, Eq, Serialize, Deserialize, Default, ConfigurationOptions)]
+#[derive(
+    Debug, PartialEq, Eq, Serialize, Deserialize, Default, ConfigurationOptions, CombineOptions,
+)]
 #[serde(
     deny_unknown_fields,
     rename_all = "kebab-case",
