@@ -6,7 +6,7 @@ use super::rules;
 
 /// An AST node that can contain arguments.
 #[derive(Copy, Clone)]
-pub enum Argumentable {
+pub(crate) enum Argumentable {
     Function,
     Method,
     ClassMethod,
@@ -15,7 +15,7 @@ pub enum Argumentable {
 }
 
 impl Argumentable {
-    pub fn check_for(self, name: String) -> DiagnosticKind {
+    pub(crate) fn check_for(self, name: String) -> DiagnosticKind {
         match self {
             Self::Function => rules::UnusedFunctionArgument { name }.into(),
             Self::Method => rules::UnusedMethodArgument { name }.into(),
@@ -25,7 +25,7 @@ impl Argumentable {
         }
     }
 
-    pub const fn rule_code(self) -> Rule {
+    pub(crate) const fn rule_code(self) -> Rule {
         match self {
             Self::Function => Rule::UnusedFunctionArgument,
             Self::Method => Rule::UnusedMethodArgument,
