@@ -1,10 +1,10 @@
-use ruff_python_ast::helpers::{create_expr, unparse_expr};
-use ruff_python_ast::newlines::Line;
-use ruff_python_ast::source_code::Stylist;
 use ruff_text_size::{TextLen, TextRange};
 use rustpython_parser::ast::{self, Cmpop, Expr};
 use unicode_width::{UnicodeWidthChar, UnicodeWidthStr};
 
+use ruff_python_ast::newlines::Line;
+use ruff_python_ast::source_code::Generator;
+
 pub(crate) fn is_ambiguous_name(name: &str) -> bool {
     name == "l" || name == "I" || name == "O"
 }
@@ -13,16 +13,15 @@ pub(crate) fn compare(
     left: &Expr,
     ops: &[Cmpop],
     comparators: &[Expr],
-    stylist: &Stylist,
+    generator: Generator,
 ) -> String {
-    unparse_expr(
-        &create_expr(ast::ExprCompare {
-            left: Box::new(left.clone()),
-            ops: ops.to_vec(),
-            comparators: comparators.to_vec(),
-        }),
-        stylist,
-    )
+    let node = ast::ExprCompare {
+        left: Box::new(left.clone()),
+        ops: ops.to_vec(),
+        comparators: comparators.to_vec(),
+        range: TextRange::default(),
+    };
+    generator.expr(&node.into())
 }
 
 pub(super) fn is_overlong(
