@@ -54,7 +54,7 @@ pub(crate) fn missing_whitespace(
                 prev_lsqb = token.start();
             }
             TokenKind::Rsqb => {
-                open_parentheses += 1;
+                open_parentheses -= 1;
             }
             TokenKind::Lbrace => {
                 prev_lbrace = token.start();
@@ -63,7 +63,11 @@ pub(crate) fn missing_whitespace(
             TokenKind::Comma | TokenKind::Semi | TokenKind::Colon => {
                 let after = line.text_after(token);
 
-                if !after.chars().next().map_or(false, char::is_whitespace) {
+                if !after
+                    .chars()
+                    .next()
+                    .map_or(false, |c| char::is_whitespace(c) || c == '\\')
+                {
                     if let Some(next_token) = iter.peek() {
                         match (kind, next_token.kind()) {
                             (TokenKind::Colon, _)
