@@ -31,7 +31,10 @@ pub(crate) fn missing_whitespace_after_keyword(
                 || matches!(tok0_kind, TokenKind::Async | TokenKind::Await)
                 || tok0_kind == TokenKind::Except && tok1_kind == TokenKind::Star
                 || tok0_kind == TokenKind::Yield && tok1_kind == TokenKind::Rpar
-                || matches!(tok1_kind, TokenKind::Colon | TokenKind::Newline))
+                || matches!(
+                    tok1_kind,
+                    TokenKind::Colon | TokenKind::Newline | TokenKind::NonLogicalNewline
+                ))
             && tok0.end() == tok1.start()
         {
             context.push(MissingWhitespaceAfterKeyword, tok0.range());
