@@ -1,5 +1,5 @@
 use itertools::izip;
-use rustpython_parser::ast::{self, Cmpop, Constant, Expr, ExprKind};
+use rustpython_parser::ast::{self, Cmpop, Constant, Expr, Ranged};
 
 use crate::checkers::ast::Checker;
 use ruff_diagnostics::{Diagnostic, Violation};
@@ -47,19 +47,20 @@ pub(crate) fn type_comparison(
         if !matches!(op, Cmpop::Is | Cmpop::IsNot | Cmpop::Eq | Cmpop::NotEq) {
             continue;
         }
-        match &right.node {
-            ExprKind::Call(ast::ExprCall { func, args, .. }) => {
-                if let ExprKind::Name(ast::ExprName { id, .. }) = &func.node {
+        match right {
+            Expr::Call(ast::ExprCall { func, args, .. }) => {
+                if let Expr::Name(ast::ExprName { id, .. }) = func.as_ref() {
                     // Ex) `type(False)`
                     if id == "type" && checker.ctx.is_builtin("type") {
                         if let Some(arg) = args.first() {
                             // Allow comparison for types which are not obvious.
                             if !matches!(
-                                arg.node,
-                                ExprKind::Name(_)
-                                    | ExprKind::Constant(ast::ExprConstant {
+                                arg,
+                                Expr::Name(_)
+                                    | Expr::Constant(ast::ExprConstant {
                                         value: Constant::None,
-                                        kind: None
+                                        kind: None,
+                                        range: _
                                     })
                             ) {
                                 checker
@@ -70,8 +71,8 @@ pub(crate) fn type_comparison(
                     }
                 }
             }
-            ExprKind::Attribute(ast::ExprAttribute { value, .. }) => {
-                if let ExprKind::Name(ast::ExprName { id, .. }) = &value.node {
+            Expr::Attribute(ast::ExprAttribute { value, .. }) => {
+                if let Expr::Name(ast::ExprName { id, .. }) = value.as_ref() {
                     // Ex) `types.NoneType`
                     if id == "types"
                         && checker
