@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Expr, ExprKind, Stmt};
+use rustpython_parser::ast::{self, Expr, Ranged, Stmt};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -17,7 +17,7 @@ impl Violation for AssertTuple {
 
 /// F631
 pub(crate) fn assert_tuple(checker: &mut Checker, stmt: &Stmt, test: &Expr) {
-    if let ExprKind::Tuple(ast::ExprTuple { elts, .. }) = &test.node {
+    if let Expr::Tuple(ast::ExprTuple { elts, .. }) = &test {
         if !elts.is_empty() {
             checker
                 .diagnostics
