@@ -5,7 +5,7 @@ use ruff_text_size::TextRange;
 
 #[violation]
 pub struct UndefinedExport {
-    pub name: String,
+    name: String,
 }
 
 impl Violation for UndefinedExport {
@@ -17,7 +17,7 @@ impl Violation for UndefinedExport {
 }
 
 /// F822
-pub fn undefined_export(names: &[&str], range: TextRange, scope: &Scope) -> Vec<Diagnostic> {
+pub(crate) fn undefined_export(names: &[&str], range: TextRange, scope: &Scope) -> Vec<Diagnostic> {
     let mut diagnostics = Vec::new();
     if !scope.uses_star_imports() {
         for name in names {
