@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{self, Expr, ExprKind};
+use rustpython_parser::ast::{self, Expr, Ranged};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -40,7 +40,7 @@ impl Violation for Eval {
 
 /// PGH001
 pub(crate) fn no_eval(checker: &mut Checker, func: &Expr) {
-    let ExprKind::Name(ast::ExprName { id, .. }) = &func.node else {
+    let Expr::Name(ast::ExprName { id, .. }) = func else {
         return;
     };
     if id != "eval" {
