@@ -1,4 +1,4 @@
-use rustpython_parser::ast::Expr;
+use rustpython_parser::ast::{Expr, Ranged};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -6,6 +6,33 @@ use ruff_python_semantic::scope::{FunctionDef, ScopeKind};
 
 use crate::checkers::ast::Checker;
 
+/// ## What it does
+/// Checks for usages of `await` outside of `async` functions.
+///
+/// ## Why is this bad?
+/// Using `await` outside of an `async` function is a syntax error.
+///
+/// ## Example
+/// ```python
+/// import asyncio
+///
+///
+/// def foo():
+///     await asyncio.sleep(1)
+/// ```
+///
+/// Use instead:
+/// ```python
+/// import asyncio
+///
+///
+/// async def foo():
+///     await asyncio.sleep(1)
+/// ```
+///
+/// ## References
+/// - [Python documentation](https://docs.python.org/3/reference/expressions.html#await)
+/// - [PEP 492](https://peps.python.org/pep-0492/#await-expression)
 #[violation]
 pub struct AwaitOutsideAsync;
 
