@@ -1,4 +1,4 @@
-use rustpython_parser::ast::{Stmt, StmtKind};
+use rustpython_parser::ast::{Ranged, Stmt};
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
@@ -18,7 +18,7 @@ impl Violation for CollapsibleElseIf {
 pub(crate) fn collapsible_else_if(orelse: &[Stmt], locator: &Locator) -> Option<Diagnostic> {
     if orelse.len() == 1 {
         let first = &orelse[0];
-        if matches!(first.node, StmtKind::If(_)) {
+        if matches!(first, Stmt::If(_)) {
             // Determine whether this is an `elif`, or an `if` in an `else` block.
             if locator.slice(first.range()).starts_with("if") {
                 return Some(Diagnostic::new(CollapsibleElseIf, first.range()));
