@@ -8,6 +8,7 @@ pub(crate) use collapsible_else_if::{collapsible_else_if, CollapsibleElseIf};
 pub(crate) use compare_to_empty_string::{compare_to_empty_string, CompareToEmptyString};
 pub(crate) use comparison_of_constant::{comparison_of_constant, ComparisonOfConstant};
 pub(crate) use continue_in_finally::{continue_in_finally, ContinueInFinally};
+pub(crate) use duplicate_bases::{duplicate_bases, DuplicateBases};
 pub(crate) use global_statement::{global_statement, GlobalStatement};
 pub(crate) use global_variable_not_assigned::GlobalVariableNotAssigned;
 pub(crate) use import_self::{import_from_self, import_self, ImportSelf};
@@ -57,6 +58,7 @@ mod collapsible_else_if;
 mod compare_to_empty_string;
 mod comparison_of_constant;
 mod continue_in_finally;
+mod duplicate_bases;
 mod global_statement;
 mod global_variable_not_assigned;
 mod import_self;
