@@ -1,7 +1,7 @@
 //! Settings for the `pylint` plugin.
 
 use anyhow::anyhow;
-use ruff_macros::{CacheKey, ConfigurationOptions};
+use ruff_macros::{CacheKey, CombineOptions, ConfigurationOptions};
 use rustpython_parser::ast::Constant;
 use serde::{Deserialize, Serialize};
 
@@ -35,7 +35,9 @@ impl TryFrom<&Constant> for ConstantType {
     }
 }
 
-#[derive(Debug, PartialEq, Eq, Serialize, Deserialize, Default, ConfigurationOptions)]
+#[derive(
+    Debug, PartialEq, Eq, Serialize, Deserialize, Default, ConfigurationOptions, CombineOptions,
+)]
 #[serde(
     deny_unknown_fields,
     rename_all = "kebab-case",
