@@ -1,13 +1,12 @@
 use anyhow::{bail, Result};
 use log::debug;
-use rustpython_parser::ast::{
-    self, Constant, Expr, ExprContext, ExprKind, Keyword, Stmt, StmtKind,
-};
+use ruff_text_size::TextRange;
+use rustpython_parser::ast::{self, Constant, Expr, ExprContext, Keyword, Ranged, Stmt};
 
 use ruff_diagnostics::{AutofixKind, Diagnostic, Edit, Fix, Violation};
 use ruff_macros::{derive_message_formats, violation};
-use ruff_python_ast::helpers::{create_expr, create_stmt, unparse_stmt};
-use ruff_python_ast::source_code::Stylist;
+
+use ruff_python_ast::source_code::Generator;
 use ruff_python_stdlib::identifiers::is_identifier;
 
 use crate::checkers::ast::Checker;
@@ -42,14 +41,15 @@ fn match_typed_dict_assign<'a>(
     value: &'a Expr,
 ) -> Option<(&'a str, &'a [Expr], &'a [Keyword], &'a Expr)> {
     let target = targets.get(0)?;
-    let ExprKind::Name(ast::ExprName { id: class_name, .. }) = &target.node else {
+    let Expr::Name(ast::ExprName { id: class_name, .. }) = target else {
         return None;
     };
-    let ExprKind::Call(ast::ExprCall {
+    let Expr::Call(ast::ExprCall {
         func,
         args,
         keywords,
-    }) = &value.node else {
+        range: _
+    }) = value else {
         return None;
     };
     if !checker
@@ -64,18 +64,23 @@ fn match_typed_dict_assign<'a>(
     Some((class_name, args, keywords, func))
 }
 
-/// Generate a `StmtKind::AnnAssign` representing the provided property
+/// Generate a `Stmt::AnnAssign` representing the provided property
 /// definition.
-fn create_property_assignment_stmt(property: &str, annotation: &ExprKind) -> Stmt {
-    create_stmt(ast::StmtAnnAssign {
-        target: Box::new(create_expr(ast::ExprName {
-            id: property.into(),
-            ctx: ExprContext::Load,
-        })),
-        annotation: Box::new(create_expr(annotation.clone())),
+fn create_property_assignment_stmt(property: &str, annotation: &Expr) -> Stmt {
+    let node = annotation.clone();
+    let node1 = ast::ExprName {
+        id: property.into(),
+        ctx: ExprContext::Load,
+        range: TextRange::default(),
+    };
+    let node2 = ast::StmtAnnAssign {
+        target: Box::new(node1.into()),
+        annotation: Box::new(node),
         value: None,
         simple: true,
-    })
+        range: TextRange::default(),
+    };
+    node2.into()
 }
 
 /// Generate a `StmtKind:ClassDef` statement based on the provided body,
@@ -90,33 +95,34 @@ fn create_class_def_stmt(
         Some(keyword) => vec![keyword.clone()],
         None => vec![],
     };
-    create_stmt(ast::StmtClassDef {
+    let node = ast::StmtClassDef {
         name: class_name.into(),
         bases: vec![base_class.clone()],
         keywords,
         body,
         decorator_list: vec![],
-    })
+        range: TextRange::default(),
+    };
+    node.into()
 }
 
 fn properties_from_dict_literal(keys: &[Option<Expr>], values: &[Expr]) -> Result<Vec<Stmt>> {
     if keys.is_empty() {
-        return Ok(vec![create_stmt(StmtKind::Pass)]);
+        let node = Stmt::Pass(ast::StmtPass {
+            range: TextRange::default(),
+        });
+        return Ok(vec![node]);
     }
 
     keys.iter()
         .zip(values.iter())
         .map(|(key, value)| match key {
-            Some(Expr {
-                node:
-                    ExprKind::Constant(ast::ExprConstant {
-                        value: Constant::Str(property),
-                        ..
-                    }),
+            Some(Expr::Constant(ast::ExprConstant {
+                value: Constant::Str(property),
                 ..
-            }) => {
+            })) => {
                 if is_identifier(property) {
-                    Ok(create_property_assignment_stmt(property, &value.node))
+                    Ok(create_property_assignment_stmt(property, value))
                 } else {
                     bail!("Property name is not valid identifier: {}", property)
                 }
@@ -127,14 +133,17 @@ fn properties_from_dict_literal(keys: &[Option<Expr>], values: &[Expr]) -> Resul
 }
 
 fn properties_from_dict_call(func: &Expr, keywords: &[Keyword]) -> Result<Vec<Stmt>> {
-    let ExprKind::Name(ast::ExprName { id, .. }) = &func.node else {
-        bail!("Expected `func` to be `ExprKind::Name`")
+    let Expr::Name(ast::ExprName { id, .. }) = func else {
+        bail!("Expected `func` to be `Expr::Name`")
     };
     if id != "dict" {
         bail!("Expected `id` to be `\"dict\"`")
     }
     if keywords.is_empty() {
-        return Ok(vec![create_stmt(StmtKind::Pass)]);
+        let node = Stmt::Pass(ast::StmtPass {
+            range: TextRange::default(),
+        });
+        return Ok(vec![node]);
     }
 
     properties_from_keywords(keywords)
@@ -143,17 +152,17 @@ fn properties_from_dict_call(func: &Expr, keywords: &[Keyword]) -> Result<Vec<St
 // Deprecated in Python 3.11, removed in Python 3.13.
 fn properties_from_keywords(keywords: &[Keyword]) -> Result<Vec<Stmt>> {
     if keywords.is_empty() {
-        return Ok(vec![create_stmt(StmtKind::Pass)]);
+        let node = Stmt::Pass(ast::StmtPass {
+            range: TextRange::default(),
+        });
+        return Ok(vec![node]);
     }
 
     keywords
         .iter()
         .map(|keyword| {
-            if let Some(property) = &keyword.node.arg {
-                Ok(create_property_assignment_stmt(
-                    property,
-                    &keyword.node.value.node,
-                ))
+            if let Some(property) = &keyword.arg {
+                Ok(create_property_assignment_stmt(property, &keyword.value))
             } else {
                 bail!("Expected `arg` to be `Some`")
             }
@@ -167,7 +176,7 @@ fn properties_from_keywords(keywords: &[Keyword]) -> Result<Vec<Stmt>> {
 // ```
 fn match_total_from_only_keyword(keywords: &[Keyword]) -> Option<&Keyword> {
     let keyword = keywords.get(0)?;
-    let arg = &keyword.node.arg.as_ref()?;
+    let arg = &keyword.arg.as_ref()?;
     match arg.as_str() {
         "total" => Some(keyword),
         _ => None,
@@ -185,19 +194,24 @@ fn match_properties_and_total<'a>(
     // ```
     if let Some(dict) = args.get(1) {
         let total = match_total_from_only_keyword(keywords);
-        match &dict.node {
-            ExprKind::Dict(ast::ExprDict { keys, values }) => {
-                Ok((properties_from_dict_literal(keys, values)?, total))
-            }
-            ExprKind::Call(ast::ExprCall { func, keywords, .. }) => {
+        match dict {
+            Expr::Dict(ast::ExprDict {
+                keys,
+                values,
+                range: _,
+            }) => Ok((properties_from_dict_literal(keys, values)?, total)),
+            Expr::Call(ast::ExprCall { func, keywords, .. }) => {
                 Ok((properties_from_dict_call(func, keywords)?, total))
             }
-            _ => bail!("Expected `arg` to be `ExprKind::Dict` or `ExprKind::Call`"),
+            _ => bail!("Expected `arg` to be `Expr::Dict` or `Expr::Call`"),
         }
     } else if !keywords.is_empty() {
         Ok((properties_from_keywords(keywords)?, None))
     } else {
-        Ok((vec![create_stmt(StmtKind::Pass)], None))
+        let node = Stmt::Pass(ast::StmtPass {
+            range: TextRange::default(),
+        });
+        Ok((vec![node], None))
     }
 }
 
@@ -208,14 +222,16 @@ fn convert_to_class(
     body: Vec<Stmt>,
     total_keyword: Option<&Keyword>,
     base_class: &Expr,
-    stylist: &Stylist,
+    generator: Generator,
 ) -> Fix {
     #[allow(deprecated)]
     Fix::unspecified(Edit::range_replacement(
-        unparse_stmt(
-            &create_class_def_stmt(class_name, body, total_keyword, base_class),
-            stylist,
-        ),
+        generator.stmt(&create_class_def_stmt(
+            class_name,
+            body,
+            total_keyword,
+            base_class,
+        )),
         stmt.range(),
     ))
 }
@@ -256,7 +272,7 @@ pub(crate) fn convert_typed_dict_functional_to_class(
             body,
             total_keyword,
             base_class,
-            checker.stylist,
+            checker.generator(),
         ));
     }
     checker.diagnostics.push(diagnostic);
