@@ -1,6 +1,6 @@
 use itertools::Itertools;
 use log::error;
-use rustpython_parser::ast::{Alias, AliasData, Attributed, Stmt};
+use rustpython_parser::ast::{Alias, Ranged, Stmt};
 
 use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
 use ruff_macros::{derive_message_formats, violation};
@@ -57,18 +57,14 @@ const PY37_PLUS_REMOVE_FUTURES: &[&str] = &[
 ];
 
 /// UP010
-pub(crate) fn unnecessary_future_import(
-    checker: &mut Checker,
-    stmt: &Stmt,
-    names: &[Attributed<AliasData>],
-) {
+pub(crate) fn unnecessary_future_import(checker: &mut Checker, stmt: &Stmt, names: &[Alias]) {
     let mut unused_imports: Vec<&Alias> = vec![];
     for alias in names {
-        if alias.node.asname.is_some() {
+        if alias.asname.is_some() {
             continue;
         }
-        if PY33_PLUS_REMOVE_FUTURES.contains(&alias.node.name.as_str())
-            || PY37_PLUS_REMOVE_FUTURES.contains(&alias.node.name.as_str())
+        if PY33_PLUS_REMOVE_FUTURES.contains(&alias.name.as_str())
+            || PY37_PLUS_REMOVE_FUTURES.contains(&alias.name.as_str())
         {
             unused_imports.push(alias);
         }
@@ -81,7 +77,7 @@ pub(crate) fn unnecessary_future_import(
         UnnecessaryFutureImport {
             names: unused_imports
                 .iter()
-                .map(|alias| alias.node.name.to_string())
+                .map(|alias| alias.name.to_string())
                 .sorted()
                 .collect(),
         },
@@ -94,7 +90,7 @@ pub(crate) fn unnecessary_future_import(
         let defined_in = checker.ctx.stmt_parent();
         let unused_imports: Vec<String> = unused_imports
             .iter()
-            .map(|alias| format!("__future__.{}", alias.node.name))
+            .map(|alias| format!("__future__.{}", alias.name))
             .collect();
         match autofix::actions::remove_unused_imports(
             unused_imports.iter().map(String::as_str),
