@@ -1,8 +1,9 @@
-use rustpython_parser::ast::{self, Expr, ExprContext, ExprKind, Operator};
+use ruff_text_size::TextRange;
+use rustpython_parser::ast::{self, Expr, ExprContext, Operator, Ranged};
 
 use ruff_diagnostics::{AutofixKind, Diagnostic, Edit, Fix, Violation};
 use ruff_macros::{derive_message_formats, violation};
-use ruff_python_ast::helpers::{create_expr, has_comments, unparse_expr};
+use ruff_python_ast::helpers::has_comments;
 
 use crate::checkers::ast::Checker;
 use crate::registry::AsRule;
@@ -33,10 +34,12 @@ fn make_splat_elts(
     splat_at_left: bool,
 ) -> Vec<Expr> {
     let mut new_elts = other_elements.to_owned();
-    let splat = create_expr(ast::ExprStarred {
+    let node = ast::ExprStarred {
         value: Box::from(splat_element.clone()),
         ctx: ExprContext::Load,
-    });
+        range: TextRange::default(),
+    };
+    let splat = node.into();
     if splat_at_left {
         new_elts.insert(0, splat);
     } else {
@@ -55,52 +58,80 @@ enum Kind {
 /// This suggestion could be unsafe if the non-literal expression in the
 /// expression has overridden the `__add__` (or `__radd__`) magic methods.
 pub(crate) fn collection_literal_concatenation(checker: &mut Checker, expr: &Expr) {
-    let ExprKind::BinOp(ast::ExprBinOp { left, op: Operator::Add, right }) = &expr.node else {
+    let Expr::BinOp(ast::ExprBinOp { left, op: Operator::Add, right, range: _ }) = expr else {
         return;
     };
 
     // Figure out which way the splat is, and what the kind of the collection is.
-    let (kind, splat_element, other_elements, splat_at_left, ctx) = match (&left.node, &right.node)
-    {
-        (ExprKind::List(ast::ExprList { elts: l_elts, ctx }), _) => {
-            (Kind::List, right, l_elts, false, ctx)
-        }
-        (ExprKind::Tuple(ast::ExprTuple { elts: l_elts, ctx }), _) => {
-            (Kind::Tuple, right, l_elts, false, ctx)
-        }
-        (_, ExprKind::List(ast::ExprList { elts: r_elts, ctx })) => {
-            (Kind::List, left, r_elts, true, ctx)
-        }
-        (_, ExprKind::Tuple(ast::ExprTuple { elts: r_elts, ctx })) => {
-            (Kind::Tuple, left, r_elts, true, ctx)
-        }
-        _ => return,
-    };
+    let (kind, splat_element, other_elements, splat_at_left, ctx) =
+        match (left.as_ref(), right.as_ref()) {
+            (
+                Expr::List(ast::ExprList {
+                    elts: l_elts,
+                    ctx,
+                    range: _,
+                }),
+                _,
+            ) => (Kind::List, right, l_elts, false, ctx),
+            (
+                Expr::Tuple(ast::ExprTuple {
+                    elts: l_elts,
+                    ctx,
+                    range: _,
+                }),
+                _,
+            ) => (Kind::Tuple, right, l_elts, false, ctx),
+            (
+                _,
+                Expr::List(ast::ExprList {
+                    elts: r_elts,
+                    ctx,
+                    range: _,
+                }),
+            ) => (Kind::List, left, r_elts, true, ctx),
+            (
+                _,
+                Expr::Tuple(ast::ExprTuple {
+                    elts: r_elts,
+                    ctx,
+                    range: _,
+                }),
+            ) => (Kind::Tuple, left, r_elts, true, ctx),
+            _ => return,
+        };
 
     // We'll be a bit conservative here; only calls, names and attribute accesses
     // will be considered as splat elements.
-    if !matches!(
-        splat_element.node,
-        ExprKind::Call(_) | ExprKind::Name(_) | ExprKind::Attribute(_)
-    ) {
+    if !(splat_element.is_call_expr()
+        || splat_element.is_name_expr()
+        || splat_element.is_attribute_expr())
+    {
         return;
     }
 
     let new_expr = match kind {
-        Kind::List => create_expr(ast::ExprList {
-            elts: make_splat_elts(splat_element, other_elements, splat_at_left),
-            ctx: ctx.clone(),
-        }),
-        Kind::Tuple => create_expr(ast::ExprTuple {
-            elts: make_splat_elts(splat_element, other_elements, splat_at_left),
-            ctx: ctx.clone(),
-        }),
+        Kind::List => {
+            let node = ast::ExprList {
+                elts: make_splat_elts(splat_element, other_elements, splat_at_left),
+                ctx: *ctx,
+                range: TextRange::default(),
+            };
+            node.into()
+        }
+        Kind::Tuple => {
+            let node = ast::ExprTuple {
+                elts: make_splat_elts(splat_element, other_elements, splat_at_left),
+                ctx: *ctx,
+                range: TextRange::default(),
+            };
+            node.into()
+        }
     };
 
     let contents = match kind {
         // Wrap the new expression in parentheses if it was a tuple
-        Kind::Tuple => format!("({})", unparse_expr(&new_expr, checker.stylist)),
-        Kind::List => unparse_expr(&new_expr, checker.stylist),
+        Kind::Tuple => format!("({})", checker.generator().expr(&new_expr)),
+        Kind::List => checker.generator().expr(&new_expr),
     };
     let fixable = !has_comments(expr, checker.locator);
 
