@@ -20,7 +20,6 @@ use crate::rules::{
     flake8_errmsg, flake8_gettext, flake8_implicit_str_concat, flake8_import_conventions,
     flake8_pytest_style, flake8_quotes, flake8_self, flake8_tidy_imports, flake8_type_checking,
     flake8_unused_arguments, isort, mccabe, pep8_naming, pycodestyle, pydocstyle, pylint,
-    pyupgrade,
 };
 use crate::settings::configuration::Configuration;
 use crate::settings::types::{FilePatternSet, PerFileIgnore, PythonVersion, SerializationFormat};
@@ -126,7 +125,6 @@ pub struct Settings {
     pub pycodestyle: pycodestyle::settings::Settings,
     pub pydocstyle: pydocstyle::settings::Settings,
     pub pylint: pylint::settings::Settings,
-    pub pyupgrade: pyupgrade::settings::Settings,
 }
 
 impl Settings {
@@ -226,7 +224,6 @@ impl Settings {
             pycodestyle: config.pycodestyle.map(Into::into).unwrap_or_default(),
             pydocstyle: config.pydocstyle.map(Into::into).unwrap_or_default(),
             pylint: config.pylint.map(Into::into).unwrap_or_default(),
-            pyupgrade: config.pyupgrade.map(Into::into).unwrap_or_default(),
         })
     }
 
