@@ -1,17 +1,18 @@
 //! Options that the user can provide via pyproject.toml.
 
+use rustc_hash::FxHashMap;
+use serde::{Deserialize, Serialize};
+
+use ruff_macros::ConfigurationOptions;
+
 use crate::rule_selector::RuleSelector;
 use crate::rules::{
     flake8_annotations, flake8_bandit, flake8_bugbear, flake8_builtins, flake8_comprehensions,
     flake8_errmsg, flake8_gettext, flake8_implicit_str_concat, flake8_import_conventions,
     flake8_pytest_style, flake8_quotes, flake8_self, flake8_tidy_imports, flake8_type_checking,
     flake8_unused_arguments, isort, mccabe, pep8_naming, pycodestyle, pydocstyle, pylint,
-    pyupgrade,
 };
 use crate::settings::types::{PythonVersion, SerializationFormat, Version};
-use ruff_macros::ConfigurationOptions;
-use rustc_hash::FxHashMap;
-use serde::{Deserialize, Serialize};
 
 #[derive(Debug, PartialEq, Eq, Serialize, Deserialize, Default, ConfigurationOptions)]
 #[serde(deny_unknown_fields, rename_all = "kebab-case")]
@@ -508,9 +509,6 @@ pub struct Options {
     #[option_group]
     /// Options for the `pylint` plugin.
     pub pylint: Option<pylint::settings::Options>,
-    #[option_group]
-    /// Options for the `pyupgrade` plugin.
-    pub pyupgrade: Option<pyupgrade::settings::Options>,
     // Tables are required to go last.
     #[option(
         default = "{}",
