@@ -5,7 +5,7 @@ use std::path::Path;
 
 use anyhow::Result;
 use itertools::Itertools;
-use ruff_diagnostics::Diagnostic;
+use ruff_diagnostics::{AutofixKind, Diagnostic};
 use rustc_hash::FxHashMap;
 use rustpython_parser::lexer::LexResult;
 
@@ -16,16 +16,17 @@ use crate::directives;
 use crate::linter::{check_path, LinterResult};
 use crate::message::{Emitter, EmitterContext, Message, TextEmitter};
 use crate::packaging::detect_package_root;
+use crate::registry::AsRule;
 use crate::rules::pycodestyle::rules::syntax_error;
 use crate::settings::{flags, Settings};
 
-pub fn test_resource_path(path: impl AsRef<Path>) -> std::path::PathBuf {
+pub(crate) fn test_resource_path(path: impl AsRef<Path>) -> std::path::PathBuf {
     Path::new("./resources/test/").join(path)
 }
 
 /// A convenient wrapper around [`check_path`], that additionally
 /// asserts that autofixes converge after 10 iterations.
-pub fn test_path(path: impl AsRef<Path>, settings: &Settings) -> Result<Vec<Message>> {
+pub(crate) fn test_path(path: impl AsRef<Path>, settings: &Settings) -> Result<Vec<Message>> {
     static MAX_ITERATIONS: usize = 10;
 
     let path = test_resource_path("fixtures").join(path);
@@ -54,7 +55,6 @@ pub fn test_path(path: impl AsRef<Path>, settings: &Settings) -> Result<Vec<Mess
         &directives,
         settings,
         flags::Noqa::Enabled,
-        flags::Autofix::Enabled,
     );
 
     let source_has_errors = error.is_some();
@@ -64,7 +64,7 @@ pub fn test_path(path: impl AsRef<Path>, settings: &Settings) -> Result<Vec<Mess
 
     if diagnostics
         .iter()
-        .any(|diagnostic| !diagnostic.fix.is_empty())
+        .any(|diagnostic| diagnostic.fix.is_some())
     {
         let mut diagnostics = diagnostics.clone();
         let mut contents = contents.clone();
@@ -105,7 +105,6 @@ pub fn test_path(path: impl AsRef<Path>, settings: &Settings) -> Result<Vec<Mess
                 &directives,
                 settings,
                 flags::Noqa::Enabled,
-                flags::Autofix::Enabled,
             );
 
             if let Some(fixed_error) = fixed_error {
@@ -143,6 +142,24 @@ Source with applied fixes:
     Ok(diagnostics
         .into_iter()
         .map(|diagnostic| {
+            let rule = diagnostic.kind.rule();
+            let fixable = diagnostic.fix.is_some();
+
+            match (fixable, rule.autofixable()) {
+                (true, AutofixKind::Sometimes | AutofixKind::Always)
+                | (false, AutofixKind::None | AutofixKind::Sometimes) => {
+                    // Ok
+                }
+                (true, AutofixKind::None) => {
+                    panic!("Rule {rule:?} is marked as non-fixable but it created a fix. Change the `Violation::AUTOFIX` to either `AutofixKind::Sometimes` or `AutofixKind::Always`");
+                },
+                (false, AutofixKind::Always) => {
+                    panic!("Rule {rule:?} is marked to always-fixable but the diagnostic has no fix. Either ensure you always emit a fix or change `Violation::AUTOFIX` to either `AutofixKind::Sometimes` or `AutofixKind::None")
+                }
+            }
+
+            assert!(!(fixable && diagnostic.kind.suggestion.is_none()), "Diagnostic emitted by {rule:?} is fixable but `Violation::autofix_title` returns `None`.`");
+
             // Not strictly necessary but adds some coverage for this code path
             let noqa = directives.noqa_line_for.resolve(diagnostic.start());
 
