@@ -12,7 +12,7 @@ use path_absolutize::path_dedot;
 const BIN_NAME: &str = "ruff";
 
 #[test]
-fn test_stdin_success() -> Result<()> {
+fn stdin_success() -> Result<()> {
     let mut cmd = Command::cargo_bin(BIN_NAME)?;
     cmd.args(["-", "--format", "text", "--isolated"])
         .write_stdin("")
@@ -22,7 +22,7 @@ fn test_stdin_success() -> Result<()> {
 }
 
 #[test]
-fn test_stdin_error() -> Result<()> {
+fn stdin_error() -> Result<()> {
     let mut cmd = Command::cargo_bin(BIN_NAME)?;
     let output = cmd
         .args(["-", "--format", "text", "--isolated"])
@@ -40,7 +40,7 @@ Found 1 error.
 }
 
 #[test]
-fn test_stdin_filename() -> Result<()> {
+fn stdin_filename() -> Result<()> {
     let mut cmd = Command::cargo_bin(BIN_NAME)?;
     let output = cmd
         .args([
@@ -66,7 +66,7 @@ Found 1 error.
 
 #[cfg(unix)]
 #[test]
-fn test_stdin_json() -> Result<()> {
+fn stdin_json() -> Result<()> {
     let mut cmd = Command::cargo_bin(BIN_NAME)?;
     let output = cmd
         .args([
@@ -127,7 +127,7 @@ fn test_stdin_json() -> Result<()> {
 }
 
 #[test]
-fn test_stdin_autofix() -> Result<()> {
+fn stdin_autofix() -> Result<()> {
     let mut cmd = Command::cargo_bin(BIN_NAME)?;
     let output = cmd
         .args(["-", "--format", "text", "--fix", "--isolated"])
@@ -142,7 +142,7 @@ fn test_stdin_autofix() -> Result<()> {
 }
 
 #[test]
-fn test_stdin_autofix_when_not_fixable_should_still_print_contents() -> Result<()> {
+fn stdin_autofix_when_not_fixable_should_still_print_contents() -> Result<()> {
     let mut cmd = Command::cargo_bin(BIN_NAME)?;
     let output = cmd
         .args(["-", "--format", "text", "--fix", "--isolated"])
@@ -157,7 +157,7 @@ fn test_stdin_autofix_when_not_fixable_should_still_print_contents() -> Result<(
 }
 
 #[test]
-fn test_stdin_autofix_when_no_issues_should_still_print_contents() -> Result<()> {
+fn stdin_autofix_when_no_issues_should_still_print_contents() -> Result<()> {
     let mut cmd = Command::cargo_bin(BIN_NAME)?;
     let output = cmd
         .args(["-", "--format", "text", "--fix", "--isolated"])
@@ -172,7 +172,7 @@ fn test_stdin_autofix_when_no_issues_should_still_print_contents() -> Result<()>
 }
 
 #[test]
-fn test_show_source() -> Result<()> {
+fn show_source() -> Result<()> {
     let mut cmd = Command::cargo_bin(BIN_NAME)?;
     let output = cmd
         .args(["-", "--format", "text", "--show-source", "--isolated"])
@@ -217,3 +217,63 @@ fn show_statistics() -> Result<()> {
     );
     Ok(())
 }
+
+#[test]
+fn nursery_prefix() -> Result<()> {
+    let mut cmd = Command::cargo_bin(BIN_NAME)?;
+
+    // `--select E` should detect E741, but not E225, which is in the nursery.
+    let output = cmd
+        .args(["-", "--format", "text", "--isolated", "--select", "E"])
+        .write_stdin("I=42\n")
+        .assert()
+        .failure();
+    assert_eq!(
+        str::from_utf8(&output.get_output().stdout)?,
+        r#"-:1:1: E741 Ambiguous variable name: `I`
+Found 1 error.
+"#
+    );
+
+    Ok(())
+}
+
+#[test]
+fn nursery_all() -> Result<()> {
+    let mut cmd = Command::cargo_bin(BIN_NAME)?;
+
+    // `--select ALL` should detect E741, but not E225, which is in the nursery.
+    let output = cmd
+        .args(["-", "--format", "text", "--isolated", "--select", "E"])
+        .write_stdin("I=42\n")
+        .assert()
+        .failure();
+    assert_eq!(
+        str::from_utf8(&output.get_output().stdout)?,
+        r#"-:1:1: E741 Ambiguous variable name: `I`
+Found 1 error.
+"#
+    );
+
+    Ok(())
+}
+
+#[test]
+fn nursery_direct() -> Result<()> {
+    let mut cmd = Command::cargo_bin(BIN_NAME)?;
+
+    // `--select E225` should detect E225.
+    let output = cmd
+        .args(["-", "--format", "text", "--isolated", "--select", "E225"])
+        .write_stdin("I=42\n")
+        .assert()
+        .failure();
+    assert_eq!(
+        str::from_utf8(&output.get_output().stdout)?,
+        r#"-:1:2: E225 Missing whitespace around operator
+Found 1 error.
+"#
+    );
+
+    Ok(())
+}
