@@ -1,10 +1,11 @@
 //! Struct used to index source code, to enable efficient lookup of tokens that
 //! are omitted from the AST (e.g., commented lines).
 
-use crate::source_code::Locator;
 use ruff_text_size::{TextRange, TextSize};
 use rustpython_parser::lexer::LexResult;
-use rustpython_parser::Tok;
+use rustpython_parser::{StringKind, Tok};
+
+use crate::source_code::Locator;
 
 pub struct Indexer {
     /// Stores the ranges of comments sorted by [`TextRange::start`] in increasing order. No two ranges are overlapping.
@@ -16,15 +17,20 @@ pub struct Indexer {
     /// The range of all triple quoted strings in the source document. The ranges are sorted by their
     /// [`TextRange::start`] position in increasing order. No two ranges are overlapping.
     triple_quoted_string_ranges: Vec<TextRange>,
+
+    /// The range of all f-string in the source document. The ranges are sorted by their
+    /// [`TextRange::start`] position in increasing order. No two ranges are overlapping.
+    f_string_ranges: Vec<TextRange>,
 }
 
 impl Indexer {
     pub fn from_tokens(tokens: &[LexResult], locator: &Locator) -> Self {
         assert!(TextSize::try_from(locator.contents().len()).is_ok());
 
-        let mut commented_lines = Vec::new();
+        let mut comment_ranges = Vec::new();
         let mut continuation_lines = Vec::new();
-        let mut string_ranges = Vec::new();
+        let mut triple_quoted_string_ranges = Vec::new();
+        let mut f_string_ranges = Vec::new();
         // Token, end
         let mut prev_end = TextSize::default();
         let mut prev_token: Option<&Tok> = None;
@@ -35,17 +41,17 @@ impl Indexer {
 
             // Get the trivia between the previous and the current token and detect any newlines.
             // This is necessary because `RustPython` doesn't emit `[Tok::Newline]` tokens
-            // between any two tokens that form a continuation nor multiple newlines in a row.
-            // That's why we have to extract the newlines "manually".
+            // between any two tokens that form a continuation. That's why we have to extract the
+            // newlines "manually".
             for (index, text) in trivia.match_indices(['\n', '\r']) {
                 if text == "\r" && trivia.as_bytes().get(index + 1) == Some(&b'\n') {
                     continue;
                 }
 
-                // Newlines after a comment or new-line never form a continuation.
+                // Newlines after a newline never form a continuation.
                 if !matches!(
                     prev_token,
-                    Some(Tok::Newline | Tok::NonLogicalNewline | Tok::Comment(..)) | None
+                    Some(Tok::Newline | Tok::NonLogicalNewline) | None
                 ) {
                     continuation_lines.push(line_start);
                 }
@@ -59,7 +65,7 @@ impl Indexer {
 
             match tok {
                 Tok::Comment(..) => {
-                    commented_lines.push(*range);
+                    comment_ranges.push(*range);
                 }
                 Tok::Newline | Tok::NonLogicalNewline => {
                     line_start = range.end();
@@ -67,7 +73,15 @@ impl Indexer {
                 Tok::String {
                     triple_quoted: true,
                     ..
-                } => string_ranges.push(*range),
+                } => {
+                    triple_quoted_string_ranges.push(*range);
+                }
+                Tok::String {
+                    kind: StringKind::FString | StringKind::RawFString,
+                    ..
+                } => {
+                    f_string_ranges.push(*range);
+                }
                 _ => {}
             }
 
@@ -75,9 +89,10 @@ impl Indexer {
             prev_end = range.end();
         }
         Self {
-            comment_ranges: commented_lines,
+            comment_ranges,
             continuation_lines,
-            triple_quoted_string_ranges: string_ranges,
+            triple_quoted_string_ranges,
+            f_string_ranges,
         }
     }
 
@@ -91,16 +106,43 @@ impl Indexer {
         &self.continuation_lines
     }
 
-    /// Return a slice of all ranges that include a triple-quoted string. The ranges are sorted by
-    /// [`TextRange::start`] in increasing order. No two ranges are overlapping.
-    pub fn triple_quoted_string_ranges(&self) -> &[TextRange] {
-        &self.triple_quoted_string_ranges
-    }
-
+    /// Returns `true` if the given offset is part of a continuation line.
     pub fn is_continuation(&self, offset: TextSize, locator: &Locator) -> bool {
         let line_start = locator.line_start(offset);
         self.continuation_lines.binary_search(&line_start).is_ok()
     }
+
+    /// Return the [`TextRange`] of the triple-quoted-string containing a given offset.
+    pub fn triple_quoted_string_range(&self, offset: TextSize) -> Option<TextRange> {
+        let Ok(string_range_index) = self.triple_quoted_string_ranges.binary_search_by(|range| {
+            if offset < range.start() {
+                std::cmp::Ordering::Greater
+            } else if range.contains(offset) {
+                std::cmp::Ordering::Equal
+            } else {
+                std::cmp::Ordering::Less
+            }
+        }) else {
+            return None;
+        };
+        Some(self.triple_quoted_string_ranges[string_range_index])
+    }
+
+    /// Return the [`TextRange`] of the f-string containing a given offset.
+    pub fn f_string_range(&self, offset: TextSize) -> Option<TextRange> {
+        let Ok(string_range_index) = self.f_string_ranges.binary_search_by(|range| {
+            if offset < range.start() {
+                std::cmp::Ordering::Greater
+            } else if range.contains(offset) {
+                std::cmp::Ordering::Equal
+            } else {
+                std::cmp::Ordering::Less
+            }
+        }) else {
+            return None;
+        };
+        Some(self.f_string_ranges[string_range_index])
+    }
 }
 
 #[cfg(test)]
@@ -197,7 +239,7 @@ import os
         let contents = r#""this is a single-quoted string""#;
         let lxr: Vec<LexResult> = lexer::lex(contents, Mode::Module).collect();
         let indexer = Indexer::from_tokens(lxr.as_slice(), &Locator::new(contents));
-        assert_eq!(indexer.triple_quoted_string_ranges(), []);
+        assert_eq!(indexer.triple_quoted_string_ranges, []);
 
         let contents = r#"
             """
@@ -207,7 +249,7 @@ import os
         let lxr: Vec<LexResult> = lexer::lex(contents, Mode::Module).collect();
         let indexer = Indexer::from_tokens(lxr.as_slice(), &Locator::new(contents));
         assert_eq!(
-            indexer.triple_quoted_string_ranges(),
+            indexer.triple_quoted_string_ranges,
             [TextRange::new(TextSize::from(13), TextSize::from(71))]
         );
 
@@ -219,7 +261,7 @@ import os
         let lxr: Vec<LexResult> = lexer::lex(contents, Mode::Module).collect();
         let indexer = Indexer::from_tokens(lxr.as_slice(), &Locator::new(contents));
         assert_eq!(
-            indexer.triple_quoted_string_ranges(),
+            indexer.triple_quoted_string_ranges,
             [TextRange::new(TextSize::from(13), TextSize::from(107))]
         );
 
@@ -236,7 +278,7 @@ import os
         let lxr: Vec<LexResult> = lexer::lex(contents, Mode::Module).collect();
         let indexer = Indexer::from_tokens(lxr.as_slice(), &Locator::new(contents));
         assert_eq!(
-            indexer.triple_quoted_string_ranges(),
+            indexer.triple_quoted_string_ranges,
             &[
                 TextRange::new(TextSize::from(13), TextSize::from(85)),
                 TextRange::new(TextSize::from(98), TextSize::from(161))
