@@ -1,10 +1,13 @@
 use ruff_text_size::TextRange;
-use rustpython_parser::ast::Attributed;
+use rustpython_parser::ast::Ranged;
 
 use crate::source_code::Locator;
 
 /// Extract the leading indentation from a line.
-pub fn indentation<'a, T>(locator: &'a Locator, located: &Attributed<T>) -> Option<&'a str> {
+pub fn indentation<'a, T>(locator: &'a Locator, located: &T) -> Option<&'a str>
+where
+    T: Ranged,
+{
     let line_start = locator.line_start(located.start());
     let indentation = &locator.contents()[TextRange::new(line_start, located.start())];
 
