@@ -10,7 +10,7 @@ pub struct FormatCmpOp<'a> {
     item: &'a CmpOp,
 }
 
-impl AsFormat<ASTFormatContext<'_>> for CmpOp {
+impl AsFormat<ASTFormatContext> for CmpOp {
     type Format<'a> = FormatCmpOp<'a>;
 
     fn format(&self) -> Self::Format<'_> {
@@ -18,7 +18,7 @@ impl AsFormat<ASTFormatContext<'_>> for CmpOp {
     }
 }
 
-impl Format<ASTFormatContext<'_>> for FormatCmpOp<'_> {
+impl Format<ASTFormatContext> for FormatCmpOp<'_> {
     fn fmt(&self, f: &mut Formatter<ASTFormatContext>) -> FormatResult<()> {
         let cmp_op = self.item;
         write!(f, [leading_comments(cmp_op)])?;
