@@ -2,17 +2,17 @@ use ruff_formatter::prelude::*;
 use ruff_formatter::{write, Format};
 
 use crate::context::ASTFormatContext;
-use crate::cst::Located;
+use crate::cst::Attributed;
 use crate::format::builders::literal;
 use crate::trivia::TriviaKind;
 
 #[derive(Debug)]
-pub struct LeadingComments<'a, T> {
-    item: &'a Located<T>,
+pub(crate) struct LeadingComments<'a, T> {
+    item: &'a Attributed<T>,
 }
 
-impl<T> Format<ASTFormatContext<'_>> for LeadingComments<'_, T> {
-    fn fmt(&self, f: &mut Formatter<ASTFormatContext<'_>>) -> FormatResult<()> {
+impl<T> Format<ASTFormatContext> for LeadingComments<'_, T> {
+    fn fmt(&self, f: &mut Formatter<ASTFormatContext>) -> FormatResult<()> {
         for trivia in &self.item.trivia {
             if trivia.relationship.is_leading() {
                 match trivia.kind {
@@ -31,17 +31,17 @@ impl<T> Format<ASTFormatContext<'_>> for LeadingComments<'_, T> {
 }
 
 #[inline]
-pub const fn leading_comments<T>(item: &Located<T>) -> LeadingComments<'_, T> {
+pub(crate) const fn leading_comments<T>(item: &Attributed<T>) -> LeadingComments<'_, T> {
     LeadingComments { item }
 }
 
 #[derive(Debug)]
-pub struct TrailingComments<'a, T> {
-    item: &'a Located<T>,
+pub(crate) struct TrailingComments<'a, T> {
+    item: &'a Attributed<T>,
 }
 
-impl<T> Format<ASTFormatContext<'_>> for TrailingComments<'_, T> {
-    fn fmt(&self, f: &mut Formatter<ASTFormatContext<'_>>) -> FormatResult<()> {
+impl<T> Format<ASTFormatContext> for TrailingComments<'_, T> {
+    fn fmt(&self, f: &mut Formatter<ASTFormatContext>) -> FormatResult<()> {
         for trivia in &self.item.trivia {
             if trivia.relationship.is_trailing() {
                 match trivia.kind {
@@ -60,17 +60,17 @@ impl<T> Format<ASTFormatContext<'_>> for TrailingComments<'_, T> {
 }
 
 #[inline]
-pub const fn trailing_comments<T>(item: &Located<T>) -> TrailingComments<'_, T> {
+pub(crate) const fn trailing_comments<T>(item: &Attributed<T>) -> TrailingComments<'_, T> {
     TrailingComments { item }
 }
 
 #[derive(Debug)]
-pub struct EndOfLineComments<'a, T> {
-    item: &'a Located<T>,
+pub(crate) struct EndOfLineComments<'a, T> {
+    item: &'a Attributed<T>,
 }
 
-impl<T> Format<ASTFormatContext<'_>> for EndOfLineComments<'_, T> {
-    fn fmt(&self, f: &mut Formatter<ASTFormatContext<'_>>) -> FormatResult<()> {
+impl<T> Format<ASTFormatContext> for EndOfLineComments<'_, T> {
+    fn fmt(&self, f: &mut Formatter<ASTFormatContext>) -> FormatResult<()> {
         let mut first = true;
         for range in self
             .item
@@ -88,17 +88,17 @@ impl<T> Format<ASTFormatContext<'_>> for EndOfLineComments<'_, T> {
 }
 
 #[inline]
-pub const fn end_of_line_comments<T>(item: &Located<T>) -> EndOfLineComments<'_, T> {
+pub(crate) const fn end_of_line_comments<T>(item: &Attributed<T>) -> EndOfLineComments<'_, T> {
     EndOfLineComments { item }
 }
 
 #[derive(Debug)]
-pub struct DanglingComments<'a, T> {
-    item: &'a Located<T>,
+pub(crate) struct DanglingComments<'a, T> {
+    item: &'a Attributed<T>,
 }
 
-impl<T> Format<ASTFormatContext<'_>> for DanglingComments<'_, T> {
-    fn fmt(&self, f: &mut Formatter<ASTFormatContext<'_>>) -> FormatResult<()> {
+impl<T> Format<ASTFormatContext> for DanglingComments<'_, T> {
+    fn fmt(&self, f: &mut Formatter<ASTFormatContext>) -> FormatResult<()> {
         for trivia in &self.item.trivia {
             if trivia.relationship.is_dangling() {
                 if let TriviaKind::OwnLineComment(range) = trivia.kind {
@@ -113,6 +113,6 @@ impl<T> Format<ASTFormatContext<'_>> for DanglingComments<'_, T> {
 }
 
 #[inline]
-pub const fn dangling_comments<T>(item: &Located<T>) -> DanglingComments<'_, T> {
+pub(crate) const fn dangling_comments<T>(item: &Attributed<T>) -> DanglingComments<'_, T> {
     DanglingComments { item }
 }
