@@ -1,4 +1,6 @@
 pub mod analyze;
 pub mod binding;
 pub mod context;
+pub mod definition;
+pub mod node;
 pub mod scope;
